/********************************************************/
/*  Módulo de gestión de los diálogos de la aplicación  */
/********************************************************/

#include <gtk/gtk.h>
#include <glib/gstdio.h>

#include "interface.h"
#include "support.h"

#include "dialogs.h"
#include "xmlfile.h"


/* Widgets de los diálogos de la aplicación */

static GtkWidget *windowSave = NULL;
static GtkWidget *entrySaveName = NULL;
static GtkWidget *buttonSaveSave = NULL;

static GtkWidget *windowAbout = NULL;

static GtkWidget *windowError = NULL;
static GtkWidget *labelErrorMessage = NULL;
static GtkWidget *labelErrorExplanation = NULL;


/* Abre el diálogo Guardar tema 
   Establece el nombre por defecto como Clearbox */
   
void open_save_dialog ()
{
  windowSave = create_windowSave ();
  entrySaveName = lookup_widget (GTK_WIDGET(windowSave), "entrySaveName");
  buttonSaveSave = lookup_widget (GTK_WIDGET(windowSave), "buttonSaveSave");

  gtk_entry_set_text (GTK_ENTRY(entrySaveName), "Clearbox");
  
  gtk_widget_show (windowSave);
}

/* Cierra el diálogo Guardar tema */

void close_save_dialog ()
{
  gtk_widget_destroy (windowSave);
  
  windowSave = NULL;
}

/* Establece el estado de los widgets dependientes del diálogo Guardar tema */

void set_options_save ()
{
  if (*gtk_entry_get_text (GTK_ENTRY(entrySaveName)) == 0)
    gtk_widget_set_sensitive (buttonSaveSave, FALSE);
  else
    gtk_widget_set_sensitive (buttonSaveSave, TRUE);
}

/* Guarda el tema con el nombre elegido*/

void save_theme ()
{
  gchar *themeName = NULL;
  
  themeName = g_path_get_basename (gtk_entry_get_text (GTK_ENTRY(entrySaveName)));
  gtk_entry_set_text (GTK_ENTRY(entrySaveName), themeName);
  write_xml_file (themeName);
  
  close_save_dialog ();
  
  g_free (themeName);
}

/* Abre el diálogo Acerca de */

void open_about_dialog ()
{
  windowAbout = create_windowAbout ();
  
  gtk_widget_show (windowAbout);
}

/* Abre el diálogo Error
   Muestra el mensaje de error que se le pasa */

void open_error_dialog (gchar *message, gchar *explanation)
{
  GString *formatedMessage;
  
  formatedMessage = g_string_new (message);
  g_string_prepend (formatedMessage, "<span weight=\"bold\" size=\"larger\">");
  g_string_append (formatedMessage, "</span>");

  windowError = create_windowError ();
  labelErrorMessage = lookup_widget (GTK_WIDGET(windowError), "labelErrorMessage");
  labelErrorExplanation = lookup_widget (GTK_WIDGET(windowError), "labelErrorExplanation");
  
  gtk_label_set_markup (GTK_LABEL(labelErrorMessage), formatedMessage->str);
  gtk_label_set_text (GTK_LABEL(labelErrorExplanation), explanation);
  
  gtk_widget_show (windowError);
  
  g_string_free (formatedMessage, TRUE);
}

/* Cierra el diálogo Error */

void close_error_dialog ()
{
  gtk_widget_destroy (windowError);

  windowError = NULL;
  labelErrorMessage = NULL;
  labelErrorExplanation = NULL;
}
