/********************************************/
/*  Módulo de construcción del fichero xml  */
/********************************************/

#include <gtk/gtk.h>
#include <glib/gstdio.h>

#include "interface.h"
#include "support.h"

#include "clearbox.h"
#include "dialogs.h"
#include "preview.h"
#include "xmlfile.h"


/* Estructura que contiene las preferencias del tema */

struct CLEARBOX_PREFS clearboxPrefs;

/* Colores especiales utilizados en la creación del tema */

GString *colorGradient1;
GString *colorGradient2;
GString *colorShine1;
GString *colorShine2;
GString *colorShadow;
GString *colorButtonFrame1;
GString *colorButtonFrame2;
GString *colorOutline;


/* Escribe el fichero xml del tema
   Lo guarda en la carpeta .themes del usuario con el nombre que se le pasa */

gboolean write_xml_file (gchar *clearboxDir)
{
  gchar *themesPath;
  gchar *clearboxPath;
  gchar *metacityPath;
  gchar *filePath;
  GIOChannel *xmlFile = NULL;
  GError *error = NULL;

  themesPath = g_build_path ("/", g_get_home_dir (), ".themes", NULL);
  if (!g_file_test (themesPath, G_FILE_TEST_IS_DIR))
    g_mkdir (themesPath, 493);
  
  clearboxPath = g_build_path ("/", themesPath, clearboxDir, NULL);
  if (!g_file_test (clearboxPath, G_FILE_TEST_IS_DIR))
    if (g_mkdir (clearboxPath, 493) != 0)
    {
      open_error_dialog (_("Error writing theme"), _("Can't create Clearbox theme folder"));
      g_free (themesPath);
      g_free (clearboxPath);
      return FALSE;
    }
  
  metacityPath = g_build_path ("/", clearboxPath, "metacity-1", NULL);
  if (!g_file_test (metacityPath, G_FILE_TEST_IS_DIR))
    if (g_mkdir (metacityPath, 493) != 0)
    {
      open_error_dialog (_("Error writing theme"), _("Can't create Metacity theme folder"));
      g_free (themesPath);
      g_free (clearboxPath);
      g_free (metacityPath);
      return FALSE;
    }

  read_options (&clearboxPrefs);
  set_clearbox_colors ();

  filePath = g_build_path ("/", metacityPath, "metacity-theme-1.xml", NULL);
  xmlFile = g_io_channel_new_file (filePath, "w", &error);
  if (xmlFile == NULL)
  {
    open_error_dialog (_("Can't create XML theme file"), error->message);
    g_free (themesPath);
    g_free (clearboxPath);
    g_free (metacityPath);
    g_free (filePath);
    return FALSE;
  }

  set_xml_header (xmlFile);
  set_xml_frame (xmlFile);
  set_xml_blank (xmlFile);
  set_xml_topbar (xmlFile);
  set_xml_borders (xmlFile);
  set_xml_buttons (xmlFile);
  set_xml_title (xmlFile);
  set_xml_styles (xmlFile);
  set_xml_set_styles (xmlFile);
  set_xml_end (xmlFile);

  g_io_channel_shutdown (xmlFile, TRUE, &error);

  unset_clearbox_colors ();
  
  g_free (themesPath);
  g_free (clearboxPath);
  g_free (metacityPath);
  g_free (filePath);
  
  return TRUE;
}

/* Establece los colores especiales del tema */

void set_clearbox_colors ()
{
  colorGradient1 = g_string_new (clearboxPrefs.colorBase);
  colorGradient2 = g_string_new (clearboxPrefs.colorBase);
  
  colorShine1 = g_string_new (clearboxPrefs.colorBase);
  colorShine2 = g_string_new (clearboxPrefs.colorBase);
  
  colorShadow = g_string_new (clearboxPrefs.colorBase);
  g_string_prepend (colorShadow, "shade/");
  g_string_append (colorShadow, "/0.7");
  
  if (clearboxPrefs.buttonStyle == CLEAR_FRAME)
  {
    colorButtonFrame1 = g_string_new ("shade/gtk:bg[NORMAL]/1.1");
    colorButtonFrame2 = g_string_new ("shade/gtk:bg[NORMAL]/0.8");
  }
  else
  {
    colorButtonFrame1 = g_string_new (clearboxPrefs.colorBase);
    g_string_prepend (colorButtonFrame1, "shade/");
    g_string_append (colorButtonFrame1, "/0.8");
    colorButtonFrame2 = g_string_new (clearboxPrefs.colorBase);
    g_string_prepend (colorButtonFrame2, "shade/");
    g_string_append (colorButtonFrame2, "/1.0");
  }
  
  colorOutline = g_string_new (clearboxPrefs.colorBase);
  g_string_prepend (colorOutline, "shade/");
  g_string_append (colorOutline, "/0.6");
  
  if (clearboxPrefs.topbarStyle == FLAT)
  {
    g_string_prepend (colorShine1, "shade/");
    g_string_append (colorShine1, "/1.2");
    g_string_prepend (colorShine2, "shade/");
    g_string_append (colorShine2, "/1.2");
  }
  else
  {
    if (clearboxPrefs.topbarStyle == CLEARBOX_IN)
    {
      if (clearboxPrefs.gradientIntensity == NORMAL)
      {
        g_string_prepend (colorGradient1, "shade/");
        g_string_append (colorGradient1, "/0.9");
        g_string_prepend (colorGradient2, "shade/");
        g_string_append (colorGradient2, "/1.1");
        g_string_prepend (colorShine1, "shade/");
        g_string_append (colorShine1, "/1.1");
        g_string_prepend (colorShine2, "shade/");
        g_string_append (colorShine2, "/1.3");
      }
      else
      {
        if (clearboxPrefs.gradientIntensity == STRONG)
        {
          g_string_prepend (colorGradient1, "shade/");
          g_string_append (colorGradient1, "/0.9");
          g_string_prepend (colorGradient2, "shade/");
          g_string_append (colorGradient2, "/1.2");
          g_string_prepend (colorShine1, "shade/");
          g_string_append (colorShine1, "/1.1");
          g_string_prepend (colorShine2, "shade/");
          g_string_append (colorShine2, "/1.4");
        }
        else
        {
          g_string_prepend (colorGradient1, "shade/");
          g_string_append (colorGradient1, "/1.0");
          g_string_prepend (colorGradient2, "shade/");
          g_string_append (colorGradient2, "/1.1");
          g_string_prepend (colorShine1, "shade/");
          g_string_append (colorShine1, "/1.2");
          g_string_prepend (colorShine2, "shade/");
          g_string_append (colorShine2, "/1.3");
        }
      }
    }
    else
    {
      if (clearboxPrefs.gradientIntensity == NORMAL)
      {
        g_string_prepend (colorGradient1, "shade/");
        g_string_append (colorGradient1, "/1.2");
        g_string_prepend (colorGradient2, "shade/");
        g_string_append (colorGradient2, "/1.0");
        g_string_prepend (colorShine1, "shade/");
        g_string_append (colorShine1, "/1.4");
        g_string_prepend (colorShine2, "shade/");
        g_string_append (colorShine2, "/1.2");
      }
      else
      {
        if (clearboxPrefs.gradientIntensity == STRONG)
        {
          g_string_prepend (colorGradient1, "shade/");
          g_string_append (colorGradient1, "/1.2");
          g_string_prepend (colorGradient2, "shade/");
          g_string_append (colorGradient2, "/0.9");
          g_string_prepend (colorShine1, "shade/");
          g_string_append (colorShine1, "/1.4");
          g_string_prepend (colorShine2, "shade/");
          g_string_append (colorShine2, "/1.1");
        }
        else
        {
          g_string_prepend (colorGradient1, "shade/");
          g_string_append (colorGradient1, "/1.1");
          g_string_prepend (colorGradient2, "shade/");
          g_string_append (colorGradient2, "/1.0");
          g_string_prepend (colorShine1, "shade/");
          g_string_append (colorShine1, "/1.3");
          g_string_prepend (colorShine2, "shade/");
          g_string_append (colorShine2, "/1.2");
        }
      }
   }
  }
}

/* Libera de memoria las variables de los colores especiales del tema */

void unset_clearbox_colors ()
{
  g_string_free (colorGradient1, TRUE);
  g_string_free (colorGradient2, TRUE);
  g_string_free (colorShine1, TRUE);
  g_string_free (colorShine2, TRUE);
  g_string_free (colorShadow, TRUE);
  g_string_free (colorOutline, TRUE);
}

/* Establece y escribe la cabecera del fichero xml */

void set_xml_header (GIOChannel *xmlFile)
{
  gsize bytes;
  GError *error = NULL;
  GString *xmlHeader;
  
  xmlHeader = g_string_new ("<?xml version=\"1.0\"?>\n");
  g_string_append (xmlHeader, "<metacity_theme>\n");
  g_string_append (xmlHeader, "<info>\n");
  g_string_append (xmlHeader, "  <name>Clearbox</name>\n");
  g_string_append (xmlHeader, "  <author>Hugo Olabera &lt;hoo@marandhu.jazztel.es&gt;</author>\n");
  g_string_append (xmlHeader, "  <copyright>&#194; Hugo Olabera, 2005</copyright>\n");
  g_string_append (xmlHeader, "  <date>Aug, 2005</date>\n");
  g_string_append (xmlHeader, "  <description>Clearbox 1.0 metacity theme</description>\n");
  g_string_append (xmlHeader, "</info>\n\n");
  
  g_io_channel_write_chars (xmlFile, xmlHeader->str, -1, &bytes, &error);
  
  g_string_free (xmlHeader, TRUE);
}

/* Establece y escribe la geometría de marcos del fichero xml */

void set_xml_frame (GIOChannel *xmlFile)
{
  gsize bytes;
  GError *error = NULL;
  gchar borderWidth[2];
  gchar buttonSide[2];
  GString *xmlFrameNormal;
  GString *xmlFrameNoBorders;
  GString *xmlFrameUtility;
  GString *xmlFrameBorder;

  g_sprintf (borderWidth, "%d", clearboxPrefs.borderWidth);
  if (clearboxPrefs.buttonStyle == DARK_FRAME)
  {
    switch (clearboxPrefs.buttonGap)
    {
      case LARGE:
        g_sprintf (buttonSide, "%d", 3);
        break;
      case MEDIUM:
        g_sprintf (buttonSide, "%d", 2);
        break;
      default:
        g_sprintf (buttonSide, "%d", 1);
    }
  }
  else
  {
    switch (clearboxPrefs.buttonGap)
    {
      case LARGE:
        g_sprintf (buttonSide, "%d", 2);
        break;
      case MEDIUM:
        g_sprintf (buttonSide, "%d", 1);
        break;
      default:
        g_sprintf (buttonSide, "%d", 0);
    }
  }
  
  xmlFrameNormal = g_string_new ("<frame_geometry name=\"normal\"");
  if (clearboxPrefs.frameStyle == ROUNDED_CORNERS)
    g_string_append (xmlFrameNormal, " rounded_top_left=\"true\" rounded_top_right=\"true\" rounded_bottom_left=\"true\" rounded_bottom_right=\"true\"");
  g_string_append (xmlFrameNormal, ">\n");
  g_string_append (xmlFrameNormal, "  <distance name=\"left_width\" value=\"");
  g_string_append (xmlFrameNormal, borderWidth);
  g_string_append (xmlFrameNormal, "\"/>\n");
  g_string_append (xmlFrameNormal, "  <distance name=\"right_width\" value=\"");
  g_string_append (xmlFrameNormal, borderWidth);
  g_string_append (xmlFrameNormal, "\"/>\n");
  g_string_append (xmlFrameNormal, "  <distance name=\"bottom_height\" value=\"");
  g_string_append (xmlFrameNormal, borderWidth);
  g_string_append (xmlFrameNormal, "\"/>\n");
  g_string_append (xmlFrameNormal, "  <distance name=\"left_titlebar_edge\" value=\"");
  if (clearboxPrefs.frameStyle == ROUNDED_CORNERS)
    g_string_append (xmlFrameNormal, "5");
  else
    g_string_append (xmlFrameNormal, "4");
  g_string_append (xmlFrameNormal, "\"/>\n");
  g_string_append (xmlFrameNormal, "  <distance name=\"right_titlebar_edge\" value=\"");
  if (clearboxPrefs.frameStyle == ROUNDED_CORNERS)
    g_string_append (xmlFrameNormal, "5");
  else
    g_string_append (xmlFrameNormal, "4");
  g_string_append (xmlFrameNormal, "\"/>\n");
  g_string_append (xmlFrameNormal, "  <distance name=\"title_vertical_pad\" value=\"4\"/>\n");
  g_string_append (xmlFrameNormal, "  <border name=\"title_border\" left=\"0\" right=\"0\" top=\"1\" bottom=\"1\"/>\n");
  g_string_append (xmlFrameNormal, "  <border name=\"button_border\" left=\"");
  g_string_append (xmlFrameNormal, buttonSide);
  g_string_append (xmlFrameNormal, "\" right=\"");
  g_string_append (xmlFrameNormal, buttonSide);
  g_string_append (xmlFrameNormal, "\" top=\"4\" bottom=\"3\"/>\n");
  g_string_append (xmlFrameNormal, "  <aspect_ratio name=\"button\" value=\"1\"/>\n");
  g_string_append (xmlFrameNormal, "</frame_geometry>\n\n");
  
  xmlFrameNoBorders = g_string_new ("<frame_geometry name=\"no_borders\" parent=\"normal\"");
  if (clearboxPrefs.frameStyle == ROUNDED_CORNERS)
    g_string_append (xmlFrameNoBorders, " rounded_top_left=\"false\" rounded_top_right=\"false\" rounded_bottom_left=\"false\" rounded_bottom_right=\"false\"");
  g_string_append (xmlFrameNoBorders, ">\n");
  g_string_append (xmlFrameNoBorders, "  <distance name=\"left_width\" value=\"0\"/>\n");
  g_string_append (xmlFrameNoBorders, "  <distance name=\"right_width\" value=\"0\"/>\n");
  g_string_append (xmlFrameNoBorders, "  <distance name=\"bottom_height\" value=\"0\"/>\n");
  g_string_append (xmlFrameNoBorders, "  <distance name=\"left_titlebar_edge\" value=\"2\"/>\n");
  g_string_append (xmlFrameNoBorders, "  <distance name=\"right_titlebar_edge\" value=\"2\"/>\n");
  g_string_append (xmlFrameNoBorders, "  <border name=\"title_border\" left=\"0\" right=\"0\" top=\"0\" bottom=\"1\"/>\n");
  g_string_append (xmlFrameNoBorders, "  <border name=\"button_border\" left=\"");
  g_string_append (xmlFrameNoBorders, buttonSide);
  g_string_append (xmlFrameNoBorders, "\" right=\"");
  g_string_append (xmlFrameNoBorders, buttonSide);
  g_string_append (xmlFrameNoBorders, "\" top=\"3\" bottom=\"3\"/>\n");
  g_string_append (xmlFrameNoBorders, "</frame_geometry>\n\n");

  xmlFrameUtility = g_string_new ("<frame_geometry name=\"utility\" parent=\"normal\" title_scale=\"small\"");
  if (clearboxPrefs.frameStyle == ROUNDED_CORNERS)
    g_string_append (xmlFrameUtility, " rounded_top_left=\"false\" rounded_top_right=\"false\" rounded_bottom_left=\"false\" rounded_bottom_right=\"false\"");
  g_string_append (xmlFrameUtility, ">\n");
  g_string_append (xmlFrameUtility, "  <distance name=\"left_width\" value=\"1\"/>\n");
  g_string_append (xmlFrameUtility, "  <distance name=\"right_width\" value=\"1\"/>\n");
  g_string_append (xmlFrameUtility, "  <distance name=\"bottom_height\" value=\"1\"/>\n");
  g_string_append (xmlFrameUtility, "  <distance name=\"left_titlebar_edge\" value=\"3\"/>\n");
  g_string_append (xmlFrameUtility, "  <distance name=\"right_titlebar_edge\" value=\"3\"/>\n");
  g_string_append (xmlFrameUtility, "  <distance name=\"title_vertical_pad\" value=\"3\"/>\n");
  g_string_append (xmlFrameUtility, "  <border name=\"button_border\" left=\"0\" right=\"0\" top=\"3\" bottom=\"2\"/>\n");
  g_string_append (xmlFrameUtility, "</frame_geometry>\n\n");

  xmlFrameBorder = g_string_new ("<frame_geometry name=\"border\" has_title=\"false\">\n");
  g_string_append (xmlFrameBorder, "  <distance name=\"left_width\" value=\"4\"/>\n");
  g_string_append (xmlFrameBorder, "  <distance name=\"right_width\" value=\"4\"/>\n");
  g_string_append (xmlFrameBorder, "  <distance name=\"bottom_height\" value=\"4\"/>\n");
  g_string_append (xmlFrameBorder, "  <distance name=\"left_titlebar_edge\" value=\"0\"/>\n");
  g_string_append (xmlFrameBorder, "  <distance name=\"right_titlebar_edge\" value=\"0\"/>\n");
  g_string_append (xmlFrameBorder, "  <distance name=\"button_width\" value=\"0\"/>\n");
  g_string_append (xmlFrameBorder, "  <distance name=\"button_height\" value=\"0\"/>\n");
  g_string_append (xmlFrameBorder, "  <distance name=\"title_vertical_pad\" value=\"4\"/>\n");
  g_string_append (xmlFrameBorder, "  <border name=\"title_border\" left=\"0\" right=\"0\" top=\"0\" bottom=\"0\"/>\n");
  g_string_append (xmlFrameBorder, "  <border name=\"button_border\" left=\"0\" right=\"0\" top=\"0\" bottom=\"0\"/>\n");
  g_string_append (xmlFrameBorder, "</frame_geometry>\n\n");

  g_io_channel_write_chars (xmlFile, xmlFrameNormal->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlFrameNoBorders->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlFrameUtility->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlFrameBorder->str, -1, &bytes, &error);

  g_string_free (xmlFrameNormal, TRUE);
  g_string_free (xmlFrameNoBorders, TRUE);
  g_string_free (xmlFrameUtility, TRUE);
  g_string_free (xmlFrameBorder, TRUE);
}

/* Establece y escribe el dibujado en blanco del fichero xml */

void set_xml_blank (GIOChannel *xmlFile)
{
  gsize bytes;
  GError *error = NULL;
  GString *xmlBlank;
  
  xmlBlank = g_string_new ("<draw_ops name=\"bg_blank\">\n");
  g_string_append (xmlBlank, "</draw_ops>\n\n");

  g_io_channel_write_chars (xmlFile, xmlBlank->str, -1, &bytes, &error);

  g_string_free (xmlBlank, TRUE);
}

/* Establece y escribe el dibujado de la barra superior del fichero xml */

void set_xml_topbar (GIOChannel *xmlFile)
{
  gsize bytes;
  GError *error = NULL;
  gchar colorizedWidth[2];
  GString *xmlTopbar;
  GString *xmlTopbarMax;
  GString *xmlLeftTitle;
  GString *xmlLeftTitleShaded;
  GString *xmlRightTitle;
  GString *xmlRightTitleShaded;
  GString *xmlBottonTitle;
  GString *xmlBottonTitleNoBorders;

  if (clearboxPrefs.borderColorized)
    g_sprintf (colorizedWidth, "%d", clearboxPrefs.borderWidth-1);
  else
    g_sprintf (colorizedWidth, "0");

  xmlTopbar = g_string_new ("<draw_ops name=\"bg_topbar\">\n");
  g_string_append (xmlTopbar, "  <gradient type=\"vertical\" x=\"0\" y=\"2\" width=\"width\" height=\"title_height+4\">\n");
  g_string_append (xmlTopbar, "    <color value=\"");
  g_string_append (xmlTopbar, colorGradient1->str);
  g_string_append (xmlTopbar, "\"/>\n");
  g_string_append (xmlTopbar, "    <color value=\"");
  g_string_append (xmlTopbar, colorGradient2->str);
  g_string_append (xmlTopbar, "\"/>\n");
  g_string_append (xmlTopbar, "  </gradient>\n");
  g_string_append (xmlTopbar, "  <line color=\"");
  g_string_append (xmlTopbar, colorShine1->str);
  g_string_append (xmlTopbar, "\" width=\"1\" x1=\"0\" y1=\"1\" x2=\"width\" y2=\"1\"/>\n");
  g_string_append (xmlTopbar, "</draw_ops>\n\n");

  xmlTopbarMax = g_string_new ("<draw_ops name=\"bg_topbar_max\">\n");
  g_string_append (xmlTopbarMax, "  <gradient type=\"vertical\" x=\"0\" y=\"1\" width=\"width\" height=\"title_height+4\">\n");
  g_string_append (xmlTopbarMax, "    <color value=\"");
  g_string_append (xmlTopbarMax, colorGradient1->str);
  g_string_append (xmlTopbarMax, "\"/>\n");
  g_string_append (xmlTopbarMax, "    <color value=\"");
  g_string_append (xmlTopbarMax, colorGradient2->str);
  g_string_append (xmlTopbarMax, "\"/>\n");
  g_string_append (xmlTopbarMax, "  </gradient>\n");
  g_string_append (xmlTopbarMax, "  <line color=\"");
  g_string_append (xmlTopbarMax, colorShine1->str);
  g_string_append (xmlTopbarMax, "\" width=\"1\" x1=\"0\" y1=\"0\" x2=\"width\" y2=\"0\"/>\n");
  g_string_append (xmlTopbarMax, "</draw_ops>\n\n");

  xmlLeftTitle = g_string_new ("<draw_ops name=\"bg_left_title\">\n");
  if (clearboxPrefs.border3D)
  {
    g_string_append (xmlLeftTitle, "  <line color=\"");
    g_string_append (xmlLeftTitle, colorShine2->str);
    g_string_append (xmlLeftTitle, "\" width=\"1\" x1=\"1\" y1=\"1\" x2=\"1\" y2=\"height\"/>\n");
  }
  if (clearboxPrefs.frameStyle == ROUNDED_CORNERS)
  {
    g_string_append (xmlLeftTitle, "  <line color=\"");
    g_string_append (xmlLeftTitle, colorOutline->str);
    g_string_append (xmlLeftTitle, "\" width=\"1\" x1=\"3\" y1=\"0\" x2=\"5\" y2=\"0\"/>\n");
    g_string_append (xmlLeftTitle, "  <line color=\"");
    g_string_append (xmlLeftTitle, colorOutline->str);
    g_string_append (xmlLeftTitle, "\" width=\"1\" x1=\"1\" y1=\"2\" x2=\"1\" y2=\"4\"/>\n");
    g_string_append (xmlLeftTitle, "  <line color=\"");
    g_string_append (xmlLeftTitle, colorOutline->str);
    g_string_append (xmlLeftTitle, "\" width=\"1\" x1=\"2\" y1=\"1\" x2=\"3\" y2=\"1\"/>\n");
    g_string_append (xmlLeftTitle, "  <line color=\"");
    g_string_append (xmlLeftTitle, colorShine1->str);
    g_string_append (xmlLeftTitle, "\" width=\"1\" x1=\"3\" y1=\"1\" x2=\"5\" y2=\"1\"/>\n");
    g_string_append (xmlLeftTitle, "  <line color=\"");
    g_string_append (xmlLeftTitle, colorShine1->str);
    g_string_append (xmlLeftTitle, "\" width=\"1\" x1=\"1\" y1=\"4\" x2=\"1\" y2=\"5\"/>\n");
    g_string_append (xmlLeftTitle, "  <line color=\"");
    g_string_append (xmlLeftTitle, colorShine1->str);
    g_string_append (xmlLeftTitle, "\" width=\"1\" x1=\"2\" y1=\"2\" x2=\"3\" y2=\"2\"/>\n");
  }
  g_string_append (xmlLeftTitle, "</draw_ops>\n\n");

  xmlLeftTitleShaded = g_string_new ("<draw_ops name=\"bg_left_title_shaded\">\n");
  if (clearboxPrefs.frameStyle == ROUNDED_CORNERS)
  {
    g_string_append (xmlLeftTitleShaded, "<include name=\"bg_left_title\"/>\n");
    g_string_append (xmlLeftTitleShaded, "  <line color=\"");
    g_string_append (xmlLeftTitleShaded, colorOutline->str);
    g_string_append (xmlLeftTitleShaded, "\" width=\"1\" x1=\"3\" y1=\"height-1\" x2=\"5\" y2=\"height-1\"/>\n");
    g_string_append (xmlLeftTitleShaded, "  <line color=\"");
    g_string_append (xmlLeftTitleShaded, colorOutline->str);
    g_string_append (xmlLeftTitleShaded, "\" width=\"1\" x1=\"1\" y1=\"height-4\" x2=\"1\" y2=\"height-2\"/>\n");
    g_string_append (xmlLeftTitleShaded, "  <line color=\"");
    g_string_append (xmlLeftTitleShaded, colorOutline->str);
    g_string_append (xmlLeftTitleShaded, "\" width=\"1\" x1=\"2\" y1=\"height-2\" x2=\"3\" y2=\"height-2\"/>\n");
  }
  g_string_append (xmlLeftTitleShaded, "</draw_ops>\n\n");

  xmlRightTitle = g_string_new ("<draw_ops name=\"bg_right_title\">\n");
  if (clearboxPrefs.frameStyle == ROUNDED_CORNERS)
  {
    g_string_append (xmlRightTitle, "  <line color=\"");
    g_string_append (xmlRightTitle, colorOutline->str);
    g_string_append (xmlRightTitle, "\" width=\"1\" x1=\"width-5\" y1=\"0\" x2=\"width-3\" y2=\"0\"/>\n");
    g_string_append (xmlRightTitle, "  <line color=\"");
    g_string_append (xmlRightTitle, colorOutline->str);
    g_string_append (xmlRightTitle, "\" width=\"1\" x1=\"width-2\" y1=\"2\" x2=\"width-2\" y2=\"4\"/>\n");
    g_string_append (xmlRightTitle, "  <line color=\"");
    g_string_append (xmlRightTitle, colorOutline->str);
    g_string_append (xmlRightTitle, "\" width=\"1\" x1=\"width-3\" y1=\"1\" x2=\"width-2\" y2=\"1\"/>\n");
    g_string_append (xmlRightTitle, "  <line color=\"");
    g_string_append (xmlRightTitle, colorShine1->str);
    g_string_append (xmlRightTitle, "\" width=\"1\" x1=\"width-5\" y1=\"1\" x2=\"width-3\" y2=\"1\"/>\n");
    g_string_append (xmlRightTitle, "  <line color=\"");
    g_string_append (xmlRightTitle, colorShine1->str);
    g_string_append (xmlRightTitle, "\" width=\"1\" x1=\"width-2\" y1=\"4\" x2=\"width-2\" y2=\"5\"/>\n");
    g_string_append (xmlRightTitle, "  <line color=\"");
    g_string_append (xmlRightTitle, colorShine1->str);
    g_string_append (xmlRightTitle, "\" width=\"1\" x1=\"width-3\" y1=\"2\" x2=\"width-2\" y2=\"2\"/>\n");
  }
  g_string_append (xmlRightTitle, "</draw_ops>\n\n");

  xmlRightTitleShaded = g_string_new ("<draw_ops name=\"bg_right_title_shaded\">\n");
  if (clearboxPrefs.frameStyle)
  {
    g_string_append (xmlRightTitleShaded, "<include name=\"bg_right_title\"/>\n");
    g_string_append (xmlRightTitleShaded, "  <line color=\"");
    g_string_append (xmlRightTitleShaded, colorOutline->str);
    g_string_append (xmlRightTitleShaded, "\" width=\"1\" x1=\"width-5\" y1=\"height-1\" x2=\"width-3\" y2=\"height-1\"/>\n");
    g_string_append (xmlRightTitleShaded, "  <line color=\"");
    g_string_append (xmlRightTitleShaded, colorOutline->str);
    g_string_append (xmlRightTitleShaded, "\" width=\"1\" x1=\"width-2\" y1=\"height-4\" x2=\"width-2\" y2=\"height-2\"/>\n");
    g_string_append (xmlRightTitleShaded, "  <line color=\"");
    g_string_append (xmlRightTitleShaded, colorOutline->str);
    g_string_append (xmlRightTitleShaded, "\" width=\"1\" x1=\"width-3\" y1=\"height-2\" x2=\"width-2\" y2=\"height-2\"/>\n");
  }
  g_string_append (xmlRightTitleShaded, "</draw_ops>\n\n");

  xmlBottonTitle = g_string_new ("<draw_ops name=\"bg_bottom_title\">\n");
  if (clearboxPrefs.interiorOutline)
  {
    g_string_append (xmlBottonTitle, "  <line color=\"");
    g_string_append (xmlBottonTitle, colorOutline->str);
    g_string_append (xmlBottonTitle, "\" width=\"1\" x1=\"");
    g_string_append (xmlBottonTitle, colorizedWidth);
    g_string_append (xmlBottonTitle, "\" y1=\"0\" x2=\"width-");
    g_string_append (xmlBottonTitle, colorizedWidth);
    g_string_append (xmlBottonTitle, "\" y2=\"0\"/>\n");
  }
  g_string_append (xmlBottonTitle, "</draw_ops>\n\n");

  xmlBottonTitleNoBorders = g_string_new ("<draw_ops name=\"bg_bottom_title_no_borders\">\n");
  if (clearboxPrefs.interiorOutline)
  {
    g_string_append (xmlBottonTitleNoBorders, "  <line color=\"");
    g_string_append (xmlBottonTitleNoBorders, colorOutline->str);
    g_string_append (xmlBottonTitleNoBorders, "\" width=\"1\" x1=\"0\" y1=\"0\" x2=\"width\" y2=\"0\"/>\n");
  }
  g_string_append (xmlBottonTitleNoBorders, "</draw_ops>\n\n");

  g_io_channel_write_chars (xmlFile, xmlTopbar->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlTopbarMax->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlLeftTitle->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlLeftTitleShaded->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlRightTitle->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlRightTitleShaded->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlBottonTitle->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlBottonTitleNoBorders->str, -1, &bytes, &error);

  g_string_free (xmlTopbar, TRUE);
  g_string_free (xmlTopbarMax, TRUE);
  g_string_free (xmlLeftTitle, TRUE);
  g_string_free (xmlLeftTitleShaded, TRUE);
  g_string_free (xmlRightTitle, TRUE);
  g_string_free (xmlRightTitleShaded, TRUE);
  g_string_free (xmlBottonTitle, TRUE);
  g_string_free (xmlBottonTitleNoBorders, TRUE);
}

/* Establece y escribe el dibujado de los bordes del fichero xml */

void set_xml_borders (GIOChannel *xmlFile)
{
  gsize bytes;
  GError *error = NULL;
  gchar borderWidth[2];
  gchar colorizedWidth[2];
  gchar colorizedWidth3D[2];
  GString *xmlBorders;
  GString *xmlOutline;
  GString *xmlBottonOutline;
  GString *xmlWindowNoBorders;
  GString *xmlWindowBorders;
  
  g_sprintf (borderWidth, "%d", clearboxPrefs.borderWidth);
  g_sprintf (colorizedWidth, "%d", clearboxPrefs.borderWidth-1);
  g_sprintf (colorizedWidth3D, "%d", clearboxPrefs.borderWidth-2);

  xmlBorders = g_string_new ("<draw_ops name=\"bg_borders\">\n");
  if (clearboxPrefs.borderColorized)
  {
    g_string_append (xmlBorders, "  <tint color=\"");
    g_string_append (xmlBorders, colorGradient2->str);
    g_string_append (xmlBorders, "\" alpha=\"1\" x=\"1\" y=\"top_height\" width=\"");
    g_string_append (xmlBorders, colorizedWidth);
    g_string_append (xmlBorders, "\" height=\"height-top_height-1\"/>\n");
    g_string_append (xmlBorders, "  <tint color=\"");
    g_string_append (xmlBorders, colorGradient2->str);
    g_string_append (xmlBorders, "\" alpha=\"1\" x=\"width-");
    g_string_append (xmlBorders, borderWidth);
    g_string_append (xmlBorders, "\" y=\"top_height\" width=\"");
    g_string_append (xmlBorders, colorizedWidth);
    g_string_append (xmlBorders, "\" height=\"height-top_height-1\"/>\n");
    g_string_append (xmlBorders, "  <tint color=\"");
    g_string_append (xmlBorders, colorGradient2->str);
    g_string_append (xmlBorders, "\" alpha=\"1\" x=\"1\" y=\"height-");
    g_string_append (xmlBorders, borderWidth);
    g_string_append (xmlBorders, "\" width=\"width-2\" height=\"");
    g_string_append (xmlBorders, colorizedWidth);
    g_string_append (xmlBorders, "\"/>\n");
    if (clearboxPrefs.interiorOutline)
    {
      g_string_append (xmlBorders, "  <line color=\"");
      g_string_append (xmlBorders, colorOutline->str);
      g_string_append (xmlBorders, "\" width=\"1\" x1=\"");
      g_string_append (xmlBorders, colorizedWidth);
      g_string_append (xmlBorders, "\" y1=\"top_height\" x2=\"");
      g_string_append (xmlBorders, colorizedWidth);
      g_string_append (xmlBorders, "\" y2=\"height-");
      g_string_append (xmlBorders, colorizedWidth);
      g_string_append (xmlBorders, "\"/>\n");
      g_string_append (xmlBorders, "  <line color=\"");
      g_string_append (xmlBorders, colorOutline->str);
      g_string_append (xmlBorders, "\" width=\"1\" x1=\"width-");
      g_string_append (xmlBorders, borderWidth);
      g_string_append (xmlBorders, "\" y1=\"top_height\" x2=\"width-");
      g_string_append (xmlBorders, borderWidth);
      g_string_append (xmlBorders, "\" y2=\"height-");
      g_string_append (xmlBorders, colorizedWidth);
      g_string_append (xmlBorders, "\"/>\n");
      g_string_append (xmlBorders, "  <line color=\"");
      g_string_append (xmlBorders, colorOutline->str);
      g_string_append (xmlBorders, "\" width=\"1\" x1=\"");
      g_string_append (xmlBorders, colorizedWidth);
      g_string_append (xmlBorders, "\" y1=\"height-");
      g_string_append (xmlBorders, borderWidth);
      g_string_append (xmlBorders, "\" x2=\"width-");
      g_string_append (xmlBorders, colorizedWidth);
      g_string_append (xmlBorders, "\" y2=\"height-");
      g_string_append (xmlBorders, borderWidth);
      g_string_append (xmlBorders, "\"/>\n");
      if (clearboxPrefs.border3D)
      {
        g_string_append (xmlBorders, "  <line color=\"");
        g_string_append (xmlBorders, colorShine2->str);
        g_string_append (xmlBorders, "\" width=\"1\" x1=\"1\" y1=\"top_height-1\" x2=\"1\" y2=\"height-1\"/>\n");
        g_string_append (xmlBorders, "  <line color=\"");
        g_string_append (xmlBorders, colorShine2->str);
        g_string_append (xmlBorders, "\" width=\"1\" x1=\"width-");
        g_string_append (xmlBorders, colorizedWidth);
        g_string_append (xmlBorders, "\" y1=\"top_height\" x2=\"width-");
        g_string_append (xmlBorders, colorizedWidth);
        g_string_append (xmlBorders, "\" y2=\"height-");
        g_string_append (xmlBorders, colorizedWidth3D);
        g_string_append (xmlBorders, "\"/>\n");
        g_string_append (xmlBorders, "  <line color=\"");
        g_string_append (xmlBorders, colorShine2->str);
        g_string_append (xmlBorders, "\" width=\"1\" x1=\"");
        g_string_append (xmlBorders, borderWidth);
        g_string_append (xmlBorders, "\" y1=\"height-");
        g_string_append (xmlBorders, colorizedWidth);
        g_string_append (xmlBorders, "\" x2=\"width-");
        g_string_append (xmlBorders, colorizedWidth3D);
        g_string_append (xmlBorders, "\" y2=\"height-");
        g_string_append (xmlBorders, colorizedWidth);
        g_string_append (xmlBorders, "\"/>\n");
      }
    }
  }
  if (clearboxPrefs.frameStyle == ROUNDED_CORNERS)
  {
    g_string_append (xmlBorders, "  <line color=\"");
    g_string_append (xmlBorders, colorOutline->str);
    g_string_append (xmlBorders, "\" width=\"1\" x1=\"3\" y1=\"height-2\" x2=\"5\" y2=\"height-2\"/>\n");
    g_string_append (xmlBorders, "  <line color=\"");
    g_string_append (xmlBorders, colorOutline->str);
    g_string_append (xmlBorders, "\" width=\"1\" x1=\"1\" y1=\"height-5\" x2=\"1\" y2=\"height-3\"/>\n");
    g_string_append (xmlBorders, "  <line color=\"");
    g_string_append (xmlBorders, colorOutline->str);
    g_string_append (xmlBorders, "\" width=\"1\" x1=\"2\" y1=\"height-3\" x2=\"3\" y2=\"height-2\"/>\n");
    
    g_string_append (xmlBorders, "  <line color=\"");
    g_string_append (xmlBorders, colorOutline->str);
    g_string_append (xmlBorders, "\" width=\"1\" x1=\"width-5\" y1=\"height-2\" x2=\"width-3\" y2=\"height-2\"/>\n");
    g_string_append (xmlBorders, "  <line color=\"");
    g_string_append (xmlBorders, colorOutline->str);
    g_string_append (xmlBorders, "\" width=\"1\" x1=\"width-2\" y1=\"height-5\" x2=\"width-2\" y2=\"height-3\"/>\n");
    g_string_append (xmlBorders, "  <line color=\"");
    g_string_append (xmlBorders, colorOutline->str);
    g_string_append (xmlBorders, "\" width=\"1\" x1=\"width-3\" y1=\"height-3\" x2=\"width-3\" y2=\"height-2\"/>\n");
  }
  g_string_append (xmlBorders, "</draw_ops>\n\n");

  xmlOutline = g_string_new ("<draw_ops name=\"outline\">\n");
  g_string_append (xmlOutline, "  <rectangle color=\"");
  g_string_append (xmlOutline, colorOutline->str);
  g_string_append (xmlOutline, "\" x=\"0\" y=\"0\" width=\"width-1\" height=\"height-1\"/>\n");
  g_string_append (xmlOutline, "</draw_ops>\n\n");

  xmlBottonOutline = g_string_new ("<draw_ops name=\"botton_outline\">\n");
  g_string_append (xmlBottonOutline, "  <line color=\"");
  g_string_append (xmlBottonOutline, colorOutline->str);
  g_string_append (xmlBottonOutline, "\" width=\"1\" x1=\"0\" y1=\"0\" x2=\"width\" y2=\"0\"/>\n");
  g_string_append (xmlBottonOutline, "</draw_ops>\n\n");

  xmlWindowNoBorders = g_string_new ("<draw_ops name=\"bg_window_no_borders\">\n");
  g_string_append (xmlWindowNoBorders, "  <include name=\"bg_topbar\"/>\n");
  g_string_append (xmlWindowNoBorders, "  <include name=\"outline\"/>\n");
  g_string_append (xmlWindowNoBorders, "</draw_ops>\n\n");

  xmlWindowBorders = g_string_new ("<draw_ops name=\"bg_window_borders\">\n");
  g_string_append (xmlWindowBorders, "  <include name=\"bg_window_no_borders\"/>\n");
  g_string_append (xmlWindowBorders, "  <include name=\"bg_borders\"/>\n");
  g_string_append (xmlWindowBorders, "</draw_ops>\n\n");

  g_io_channel_write_chars (xmlFile, xmlBorders->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlOutline->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlBottonOutline->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlWindowNoBorders->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlWindowBorders->str, -1, &bytes, &error);

  g_string_free (xmlBorders, TRUE);
  g_string_free (xmlOutline, TRUE);
  g_string_free (xmlBottonOutline, TRUE);
  g_string_free (xmlWindowNoBorders, TRUE);
  g_string_free (xmlWindowBorders, TRUE);
}

/* Establece y escribe el dibujado de los botones del fichero xml */

void set_xml_buttons (GIOChannel *xmlFile)
{
  gsize bytes;
  GError *error = NULL;
  GString *xmlPad;
  GString *xmlFrame;
  GString *xmlFramePrelight;
  GString *xmlFramePressed;
  GString *xmlMenuNormal;
  GString *xmlMenuPressed;
  GString *xmlMenuPrelight;
  GString *xmlMenuUnfocused;
  GString *xmlMenuUnfocusedPrelight;
  GString *xmlMinimizeNormal;
  GString *xmlMinimizePressed;
  GString *xmlMinimizePrelight;
  GString *xmlMinimizeUnfocused;
  GString *xmlMinimizeUnfocusedPrelight;
  GString *xmlMaximizeNormal;
  GString *xmlMaximizePressed;
  GString *xmlMaximizePrelight;
  GString *xmlMaximizeUnfocused;
  GString *xmlMaximizeUnfocusedPrelight;
  GString *xmlRestoreNormal;
  GString *xmlRestorePressed;
  GString *xmlRestorePrelight;
  GString *xmlRestoreUnfocused;
  GString *xmlRestoreUnfocusedPrelight;
  GString *xmlCloseNormal;
  GString *xmlClosePressed;
  GString *xmlClosePrelight;
  GString *xmlCloseUnfocused;
  GString *xmlCloseUnfocusedPrelight;

  if (clearboxPrefs.buttonStyle == SIMPLE)
  {
    switch (clearboxPrefs.buttonSize)
    {
      case MEDIUM:
        xmlPad = g_string_new ("<constant name=\"ButtonPad\" value=\"4\"/>\n");
        g_string_append (xmlPad, "<constant name=\"PrelightPad\" value=\"3\"/>\n\n");
        break;
      case LARGE:
        xmlPad = g_string_new ("<constant name=\"ButtonPad\" value=\"3\"/>\n");
        g_string_append (xmlPad, "<constant name=\"PrelightPad\" value=\"2\"/>\n\n");
        break;
      default:
        xmlPad = g_string_new ("<constant name=\"ButtonPad\" value=\"5\"/>\n");
        g_string_append (xmlPad, "<constant name=\"PrelightPad\" value=\"4\"/>\n\n");
    }
  }
  else
  {
    xmlPad = g_string_new ("<constant name=\"ButtonPad\" value=\"5\"/>\n");
    g_string_append (xmlPad, "<constant name=\"PrelightPad\" value=\"5\"/>\n\n");
  }

  xmlFrame = g_string_new ("<draw_ops name=\"bg_button\">\n");
  if (clearboxPrefs.buttonStyle == DARK_FRAME)
  {
    g_string_append (xmlFrame, "  <tint color=\"");
    g_string_append (xmlFrame, colorButtonFrame1->str);
    g_string_append (xmlFrame, "\" alpha=\"1\" x=\"1\" y=\"1\" width=\"width-2\" height=\"height-2\"/>\n");
    g_string_append (xmlFrame, "  <line color=\"");
    g_string_append (xmlFrame, colorShine1->str);
    g_string_append (xmlFrame, "\" width=\"1\" x1=\"2\" y1=\"0\" x2=\"width-2\" y2=\"0\"/>\n");
    g_string_append (xmlFrame, "  <line color=\"");
    g_string_append (xmlFrame, colorShine1->str);
    g_string_append (xmlFrame, "\" width=\"1\" x1=\"2\" y1=\"height-1\" x2=\"width-2\" y2=\"height-1\"/>\n");
    g_string_append (xmlFrame, "  <line color=\"");
    g_string_append (xmlFrame, colorShine1->str);
    g_string_append (xmlFrame, "\" width=\"1\" x1=\"0\" y1=\"2\" x2=\"0\" y2=\"height-2\"/>\n");
    g_string_append (xmlFrame, "  <line color=\"");
    g_string_append (xmlFrame, colorShine1->str);
    g_string_append (xmlFrame, "\" width=\"1\" x1=\"width-1\" y1=\"2\" x2=\"width-1\" y2=\"height-2\"/>\n");
    g_string_append (xmlFrame, "  <line color=\"");
    g_string_append (xmlFrame, colorShine1->str);
    g_string_append (xmlFrame, "\" width=\"1\" x1=\"1\" y1=\"1\" x2=\"2\" y2=\"1\"/>\n");
    g_string_append (xmlFrame, "  <line color=\"");
    g_string_append (xmlFrame, colorShine1->str);
    g_string_append (xmlFrame, "\" width=\"1\" x1=\"width-2\" y1=\"1\" x2=\"width-1\" y2=\"1\"/>\n");
    g_string_append (xmlFrame, "  <line color=\"");
    g_string_append (xmlFrame, colorShine1->str);
    g_string_append (xmlFrame, "\" width=\"1\" x1=\"1\" y1=\"height-2\" x2=\"2\" y2=\"height-2\"/>\n");
    g_string_append (xmlFrame, "  <line color=\"");
    g_string_append (xmlFrame, colorShine1->str);
    g_string_append (xmlFrame, "\" width=\"1\" x1=\"width-2\" y1=\"height-2\" x2=\"width-1\" y2=\"height-2\"/>\n");
  }
  else
  {
    if (clearboxPrefs.buttonStyle == CLEAR_FRAME)
    {
      g_string_append (xmlFrame, "  <gradient type=\"vertical\" x=\"2\" y=\"2\" width=\"width-4\" height=\"height-4\">\n");
      g_string_append (xmlFrame, "    <color value=\"");
      g_string_append (xmlFrame, colorButtonFrame1->str);
      g_string_append (xmlFrame, "\"/>\n");
      g_string_append (xmlFrame, "    <color value=\"");
      g_string_append (xmlFrame, colorButtonFrame2->str);
      g_string_append (xmlFrame, "\"/>\n");
      g_string_append (xmlFrame, "  </gradient>\n");
      g_string_append (xmlFrame, "  <line color=\"");
      g_string_append (xmlFrame, colorShadow->str);
      g_string_append (xmlFrame, "\" width=\"1\" x1=\"3\" y1=\"1\" x2=\"width-3\" y2=\"1\"/>\n");
      g_string_append (xmlFrame, "  <line color=\"");
      g_string_append (xmlFrame, colorShadow->str);
      g_string_append (xmlFrame, "\" width=\"1\" x1=\"3\" y1=\"height-2\" x2=\"width-3\" y2=\"height-2\"/>\n");
      g_string_append (xmlFrame, "  <line color=\"");
      g_string_append (xmlFrame, colorShadow->str);
      g_string_append (xmlFrame, "\" width=\"1\" x1=\"1\" y1=\"3\" x2=\"1\" y2=\"height-3\"/>\n");
      g_string_append (xmlFrame, "  <line color=\"");
      g_string_append (xmlFrame, colorShadow->str);
      g_string_append (xmlFrame, "\" width=\"1\" x1=\"width-2\" y1=\"3\" x2=\"width-2\" y2=\"height-3\"/>\n");
      g_string_append (xmlFrame, "  <line color=\"");
      g_string_append (xmlFrame, colorShadow->str);
      g_string_append (xmlFrame, "\" width=\"1\" x1=\"2\" y1=\"2\" x2=\"3\" y2=\"2\"/>\n");
      g_string_append (xmlFrame, "  <line color=\"");
      g_string_append (xmlFrame, colorShadow->str);
      g_string_append (xmlFrame, "\" width=\"1\" x1=\"width-3\" y1=\"2\" x2=\"width-2\" y2=\"2\"/>\n");
      g_string_append (xmlFrame, "  <line color=\"");
      g_string_append (xmlFrame, colorShadow->str);
      g_string_append (xmlFrame, "\" width=\"1\" x1=\"2\" y1=\"height-3\" x2=\"3\" y2=\"height-3\"/>\n");
      g_string_append (xmlFrame, "  <line color=\"");
      g_string_append (xmlFrame, colorShadow->str);
      g_string_append (xmlFrame, "\" width=\"1\" x1=\"width-3\" y1=\"height-3\" x2=\"width-2\" y2=\"height-3\"/>\n");
    }
  }
  g_string_append (xmlFrame, "</draw_ops>\n\n");

  xmlFramePrelight = g_string_new ("<draw_ops name=\"bg_button_prelight\">\n");
  if (clearboxPrefs.buttonStyle == DARK_FRAME)
  {
    g_string_append (xmlFramePrelight, "  <tint color=\"");
    g_string_append (xmlFramePrelight, colorButtonFrame2->str);
    g_string_append (xmlFramePrelight, "\" alpha=\"1\" x=\"1\" y=\"1\" width=\"width-2\" height=\"height-2\"/>\n");
    g_string_append (xmlFramePrelight, "  <line color=\"");
    g_string_append (xmlFramePrelight, colorShine1->str);
    g_string_append (xmlFramePrelight, "\" width=\"1\" x1=\"2\" y1=\"0\" x2=\"width-2\" y2=\"0\"/>\n");
    g_string_append (xmlFramePrelight, "  <line color=\"");
    g_string_append (xmlFramePrelight, colorShine1->str);
    g_string_append (xmlFramePrelight, "\" width=\"1\" x1=\"2\" y1=\"height-1\" x2=\"width-2\" y2=\"height-1\"/>\n");
    g_string_append (xmlFramePrelight, "  <line color=\"");
    g_string_append (xmlFramePrelight, colorShine1->str);
    g_string_append (xmlFramePrelight, "\" width=\"1\" x1=\"0\" y1=\"2\" x2=\"0\" y2=\"height-2\"/>\n");
    g_string_append (xmlFramePrelight, "  <line color=\"");
    g_string_append (xmlFramePrelight, colorShine1->str);
    g_string_append (xmlFramePrelight, "\" width=\"1\" x1=\"width-1\" y1=\"2\" x2=\"width-1\" y2=\"height-2\"/>\n");
    g_string_append (xmlFramePrelight, "  <line color=\"");
    g_string_append (xmlFramePrelight, colorShine1->str);
    g_string_append (xmlFramePrelight, "\" width=\"1\" x1=\"1\" y1=\"1\" x2=\"2\" y2=\"1\"/>\n");
    g_string_append (xmlFramePrelight, "  <line color=\"");
    g_string_append (xmlFramePrelight, colorShine1->str);
    g_string_append (xmlFramePrelight, "\" width=\"1\" x1=\"width-2\" y1=\"1\" x2=\"width-1\" y2=\"1\"/>\n");
    g_string_append (xmlFramePrelight, "  <line color=\"");
    g_string_append (xmlFramePrelight, colorShine1->str);
    g_string_append (xmlFramePrelight, "\" width=\"1\" x1=\"1\" y1=\"height-2\" x2=\"2\" y2=\"height-2\"/>\n");
    g_string_append (xmlFramePrelight, "  <line color=\"");
    g_string_append (xmlFramePrelight, colorShine1->str);
    g_string_append (xmlFramePrelight, "\" width=\"1\" x1=\"width-2\" y1=\"height-2\" x2=\"width-1\" y2=\"height-2\"/>\n");
  }
  g_string_append (xmlFramePrelight, "</draw_ops>\n\n");

  xmlFramePressed = g_string_new ("<draw_ops name=\"bg_button_pressed\">\n");
  if (clearboxPrefs.buttonStyle == CLEAR_FRAME)
  {
    g_string_append (xmlFramePressed, "  <gradient type=\"vertical\" x=\"2\" y=\"2\" width=\"width-4\" height=\"height-4\">\n");
    g_string_append (xmlFramePressed, "    <color value=\"");
    g_string_append (xmlFramePressed, colorButtonFrame2->str);
    g_string_append (xmlFramePressed, "\"/>\n");
    g_string_append (xmlFramePressed, "    <color value=\"");
    g_string_append (xmlFramePressed, colorButtonFrame1->str);
    g_string_append (xmlFramePressed, "\"/>\n");
    g_string_append (xmlFramePressed, "  </gradient>\n");
    g_string_append (xmlFramePressed, "  <line color=\"");
    g_string_append (xmlFramePressed, colorShadow->str);
    g_string_append (xmlFramePressed, "\" width=\"1\" x1=\"3\" y1=\"1\" x2=\"width-3\" y2=\"1\"/>\n");
    g_string_append (xmlFramePressed, "  <line color=\"");
    g_string_append (xmlFramePressed, colorShadow->str);
    g_string_append (xmlFramePressed, "\" width=\"1\" x1=\"3\" y1=\"height-2\" x2=\"width-3\" y2=\"height-2\"/>\n");
    g_string_append (xmlFramePressed, "  <line color=\"");
    g_string_append (xmlFramePressed, colorShadow->str);
    g_string_append (xmlFramePressed, "\" width=\"1\" x1=\"1\" y1=\"3\" x2=\"1\" y2=\"height-3\"/>\n");
    g_string_append (xmlFramePressed, "  <line color=\"");
    g_string_append (xmlFramePressed, colorShadow->str);
    g_string_append (xmlFramePressed, "\" width=\"1\" x1=\"width-2\" y1=\"3\" x2=\"width-2\" y2=\"height-3\"/>\n");
    g_string_append (xmlFramePressed, "  <line color=\"");
    g_string_append (xmlFramePressed, colorShadow->str);
    g_string_append (xmlFramePressed, "\" width=\"1\" x1=\"2\" y1=\"2\" x2=\"3\" y2=\"2\"/>\n");
    g_string_append (xmlFramePressed, "  <line color=\"");
    g_string_append (xmlFramePressed, colorShadow->str);
    g_string_append (xmlFramePressed, "\" width=\"1\" x1=\"width-3\" y1=\"2\" x2=\"width-2\" y2=\"2\"/>\n");
    g_string_append (xmlFramePressed, "  <line color=\"");
    g_string_append (xmlFramePressed, colorShadow->str);
    g_string_append (xmlFramePressed, "\" width=\"1\" x1=\"2\" y1=\"height-3\" x2=\"3\" y2=\"height-3\"/>\n");
    g_string_append (xmlFramePressed, "  <line color=\"");
    g_string_append (xmlFramePressed, colorShadow->str);
    g_string_append (xmlFramePressed, "\" width=\"1\" x1=\"width-3\" y1=\"height-3\" x2=\"width-2\" y2=\"height-3\"/>\n");
    }
  g_string_append (xmlFramePressed, "</draw_ops>\n\n");

  xmlMenuNormal = g_string_new ("<draw_ops name=\"menu_button\">\n");
  if (clearboxPrefs.buttonIcon)
  {
    g_string_append (xmlMenuNormal, "  <icon x=\"0\" y=\"0\" width=\"width\" height=\"height\"/>\n");
  }
  else
  {
    if (clearboxPrefs.buttonStyle != SIMPLE)
      g_string_append (xmlMenuNormal, "  <include name=\"bg_button\"/>\n");
    g_string_append (xmlMenuNormal, "  <line color=\"");
    g_string_append (xmlMenuNormal, clearboxPrefs.colorButtonFocused);
    g_string_append (xmlMenuNormal, "\" width=\"2\" x1=\"ButtonPad-1\" y1=\"ButtonPad+(height-ButtonPad)/6\" x2=\"width/2\" y2=\"height/2+(height-ButtonPad)/6+1\"/>\n");
    g_string_append (xmlMenuNormal, "  <line color=\"");
    g_string_append (xmlMenuNormal, clearboxPrefs.colorButtonFocused);
    g_string_append (xmlMenuNormal, "\" width=\"1\" x1=\"ButtonPad-2\" y1=\"ButtonPad+(height-ButtonPad)/6\" x2=\"ButtonPad-1\" y2=\"ButtonPad+(height-ButtonPad)/6\"/>\n");
    g_string_append (xmlMenuNormal, "  <line color=\"");
    g_string_append (xmlMenuNormal, clearboxPrefs.colorButtonFocused);
    g_string_append (xmlMenuNormal, "\" width=\"1\" x1=\"ButtonPad-1\" y1=\"ButtonPad+(height-ButtonPad)/6-1\" x2=\"ButtonPad-1\" y2=\"ButtonPad+(height-ButtonPad)/6\"/>\n");
    g_string_append (xmlMenuNormal, "  <line color=\"");
    g_string_append (xmlMenuNormal, clearboxPrefs.colorButtonFocused);
    g_string_append (xmlMenuNormal, "\" width=\"2\" x1=\"width/2-1\" y1=\"height/2+(height-ButtonPad)/6+1\" x2=\"width/2+width/2-ButtonPad+1\" y2=\"ButtonPad+(height-ButtonPad)/6-1\"/>\n");
  }
  g_string_append (xmlMenuNormal, "</draw_ops>\n\n");

  xmlMenuPressed = g_string_new ("<draw_ops name=\"menu_button_pressed\">\n");
  if (clearboxPrefs.buttonIcon)
  {
    g_string_append (xmlMenuPressed, "  <icon x=\"0\" y=\"0\" width=\"width\" height=\"height\"/>\n");
  }
  else
  {
    if (clearboxPrefs.buttonStyle != SIMPLE)
    {
      if (clearboxPrefs.buttonStyle == CLEAR_FRAME)
          g_string_append (xmlMenuPressed, "  <include name=\"bg_button_pressed\"/>\n");
      else
          g_string_append (xmlMenuPressed, "  <include name=\"bg_button\"/>\n");
    }
    g_string_append (xmlMenuPressed, "  <line color=\"");
    g_string_append (xmlMenuPressed, clearboxPrefs.colorButtonPressed);
    g_string_append (xmlMenuPressed, "\" width=\"2\" x1=\"PrelightPad-1\" y1=\"PrelightPad+(height-PrelightPad)/6\" x2=\"width/2\" y2=\"height/2+(height-PrelightPad)/6+1\"/>\n");
    g_string_append (xmlMenuPressed, "  <line color=\"");
    g_string_append (xmlMenuPressed, clearboxPrefs.colorButtonPressed);
    g_string_append (xmlMenuPressed, "\" width=\"1\" x1=\"PrelightPad-2\" y1=\"PrelightPad+(height-PrelightPad)/6\" x2=\"PrelightPad-1\" y2=\"PrelightPad+(height-PrelightPad)/6\"/>\n");
    g_string_append (xmlMenuPressed, "  <line color=\"");
    g_string_append (xmlMenuPressed, clearboxPrefs.colorButtonPressed);
    g_string_append (xmlMenuPressed, "\" width=\"1\" x1=\"PrelightPad-1\" y1=\"PrelightPad+(height-PrelightPad)/6-1\" x2=\"PrelightPad-1\" y2=\"PrelightPad+(height-PrelightPad)/6\"/>\n");
    g_string_append (xmlMenuPressed, "  <line color=\"");
    g_string_append (xmlMenuPressed, clearboxPrefs.colorButtonPressed);
    g_string_append (xmlMenuPressed, "\" width=\"2\" x1=\"width/2-1\" y1=\"height/2+(height-PrelightPad)/6+1\" x2=\"width/2+width/2-PrelightPad+1\" y2=\"PrelightPad+(height-PrelightPad)/6-1\"/>\n");
  }
  g_string_append (xmlMenuPressed, "</draw_ops>\n\n");

  xmlMenuPrelight = g_string_new ("<draw_ops name=\"menu_button_prelight\">\n");
  if (clearboxPrefs.buttonIcon)
  {
    g_string_append (xmlMenuPrelight, "  <icon x=\"0\" y=\"0\" width=\"width\" height=\"height\"/>\n");
  }
  else
  {
    if (clearboxPrefs.buttonStyle != SIMPLE)
    {
      if (clearboxPrefs.buttonStyle == CLEAR_FRAME)
        g_string_append (xmlMenuPrelight, "  <include name=\"bg_button\"/>\n");
      else
        g_string_append (xmlMenuPrelight, "  <include name=\"bg_button_prelight\"/>\n");
    }
    g_string_append (xmlMenuPrelight, "  <line color=\"");
    g_string_append (xmlMenuPrelight, clearboxPrefs.colorButtonFocused);
    g_string_append (xmlMenuPrelight, "\" width=\"2\" x1=\"PrelightPad-1\" y1=\"PrelightPad+(height-PrelightPad)/6\" x2=\"width/2\" y2=\"height/2+(height-PrelightPad)/6+1\"/>\n");
    g_string_append (xmlMenuPrelight, "  <line color=\"");
    g_string_append (xmlMenuPrelight, clearboxPrefs.colorButtonFocused);
    g_string_append (xmlMenuPrelight, "\" width=\"1\" x1=\"PrelightPad-2\" y1=\"PrelightPad+(height-PrelightPad)/6\" x2=\"PrelightPad-1\" y2=\"PrelightPad+(height-PrelightPad)/6\"/>\n");
    g_string_append (xmlMenuPrelight, "  <line color=\"");
    g_string_append (xmlMenuPrelight, clearboxPrefs.colorButtonFocused);
    g_string_append (xmlMenuPrelight, "\" width=\"1\" x1=\"PrelightPad-1\" y1=\"PrelightPad+(height-PrelightPad)/6-1\" x2=\"PrelightPad-1\" y2=\"PrelightPad+(height-PrelightPad)/6\"/>\n");
    g_string_append (xmlMenuPrelight, "  <line color=\"");
    g_string_append (xmlMenuPrelight, clearboxPrefs.colorButtonFocused);
    g_string_append (xmlMenuPrelight, "\" width=\"2\" x1=\"width/2-1\" y1=\"height/2+(height-PrelightPad)/6+1\" x2=\"width/2+width/2-PrelightPad+1\" y2=\"PrelightPad+(height-PrelightPad)/6-1\"/>\n");
  }
  g_string_append (xmlMenuPrelight, "</draw_ops>\n\n");

  xmlMenuUnfocused = g_string_new ("<draw_ops name=\"menu_button_unfocused\">\n");
  if (clearboxPrefs.buttonIcon)
  {
    g_string_append (xmlMenuUnfocused, "  <icon x=\"0\" y=\"0\" width=\"width\" height=\"height\"/>\n");
  }
  else
  {
    if (clearboxPrefs.buttonStyle != SIMPLE)
      g_string_append (xmlMenuUnfocused, "  <include name=\"bg_button\"/>\n");
    g_string_append (xmlMenuUnfocused, "  <line color=\"");
    g_string_append (xmlMenuUnfocused, clearboxPrefs.colorButtonUnfocused);
    g_string_append (xmlMenuUnfocused, "\" width=\"2\" x1=\"ButtonPad-1\" y1=\"ButtonPad+(height-ButtonPad)/6\" x2=\"width/2\" y2=\"height/2+(height-ButtonPad)/6+1\"/>\n");
    g_string_append (xmlMenuUnfocused, "  <line color=\"");
    g_string_append (xmlMenuUnfocused, clearboxPrefs.colorButtonUnfocused);
    g_string_append (xmlMenuUnfocused, "\" width=\"1\" x1=\"ButtonPad-2\" y1=\"ButtonPad+(height-ButtonPad)/6\" x2=\"ButtonPad-1\" y2=\"ButtonPad+(height-ButtonPad)/6\"/>\n");
    g_string_append (xmlMenuUnfocused, "  <line color=\"");
    g_string_append (xmlMenuUnfocused, clearboxPrefs.colorButtonUnfocused);
    g_string_append (xmlMenuUnfocused, "\" width=\"1\" x1=\"ButtonPad-1\" y1=\"ButtonPad+(height-ButtonPad)/6-1\" x2=\"ButtonPad-1\" y2=\"ButtonPad+(height-ButtonPad)/6\"/>\n");
    g_string_append (xmlMenuUnfocused, "  <line color=\"");
    g_string_append (xmlMenuUnfocused, clearboxPrefs.colorButtonUnfocused);
    g_string_append (xmlMenuUnfocused, "\" width=\"2\" x1=\"width/2-1\" y1=\"height/2+(height-ButtonPad)/6+1\" x2=\"width/2+width/2-ButtonPad+1\" y2=\"ButtonPad+(height-ButtonPad)/6-1\"/>\n");
  }
  g_string_append (xmlMenuUnfocused, "</draw_ops>\n\n");

  xmlMenuUnfocusedPrelight = g_string_new ("<draw_ops name=\"menu_button_unfocused_prelight\">\n");
  if (clearboxPrefs.buttonIcon)
  {
    g_string_append (xmlMenuUnfocusedPrelight, "  <icon x=\"0\" y=\"0\" width=\"width\" height=\"height\"/>\n");
  }
  else
  {
    if (clearboxPrefs.buttonStyle != SIMPLE)
    {
      if (clearboxPrefs.buttonStyle == CLEAR_FRAME)
        g_string_append (xmlMenuUnfocusedPrelight, "  <include name=\"bg_button\"/>\n");
      else
        g_string_append (xmlMenuUnfocusedPrelight, "  <include name=\"bg_button_prelight\"/>\n");
    }
    g_string_append (xmlMenuUnfocusedPrelight, "  <line color=\"");
    g_string_append (xmlMenuUnfocusedPrelight, clearboxPrefs.colorButtonUnfocused);
    g_string_append (xmlMenuUnfocusedPrelight, "\" width=\"2\" x1=\"PrelightPad-1\" y1=\"PrelightPad+(height-PrelightPad)/6\" x2=\"width/2\" y2=\"height/2+(height-PrelightPad)/6+1\"/>\n");
    g_string_append (xmlMenuUnfocusedPrelight, "  <line color=\"");
    g_string_append (xmlMenuUnfocusedPrelight, clearboxPrefs.colorButtonUnfocused);
    g_string_append (xmlMenuUnfocusedPrelight, "\" width=\"1\" x1=\"PrelightPad-2\" y1=\"PrelightPad+(height-PrelightPad)/6\" x2=\"PrelightPad-1\" y2=\"PrelightPad+(height-PrelightPad)/6\"/>\n");
    g_string_append (xmlMenuUnfocusedPrelight, "  <line color=\"");
    g_string_append (xmlMenuUnfocusedPrelight, clearboxPrefs.colorButtonUnfocused);
    g_string_append (xmlMenuUnfocusedPrelight, "\" width=\"1\" x1=\"PrelightPad-1\" y1=\"PrelightPad+(height-PrelightPad)/6-1\" x2=\"PrelightPad-1\" y2=\"PrelightPad+(height-PrelightPad)/6\"/>\n");
    g_string_append (xmlMenuUnfocusedPrelight, "  <line color=\"");
    g_string_append (xmlMenuUnfocusedPrelight, clearboxPrefs.colorButtonUnfocused);
    g_string_append (xmlMenuUnfocusedPrelight, "\" width=\"2\" x1=\"width/2-1\" y1=\"height/2+(height-PrelightPad)/6+1\" x2=\"width/2+width/2-PrelightPad+1\" y2=\"PrelightPad+(height-PrelightPad)/6-1\"/>\n");
  }
  g_string_append (xmlMenuUnfocusedPrelight, "</draw_ops>\n\n");

  xmlMinimizeNormal = g_string_new ("<draw_ops name=\"minimize_button\">\n");
  if (clearboxPrefs.buttonStyle != SIMPLE)
    g_string_append (xmlMinimizeNormal, "  <include name=\"bg_button\"/>\n");
  g_string_append (xmlMinimizeNormal, "  <line color=\"");
  g_string_append (xmlMinimizeNormal, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlMinimizeNormal, "\" width=\"3\" x1=\"ButtonPad\" y1=\"height-ButtonPad-1\" x2=\"width-ButtonPad\" y2=\"height-ButtonPad-1\"/>\n");
  g_string_append (xmlMinimizeNormal, "</draw_ops>\n\n");

  xmlMinimizePressed = g_string_new ("<draw_ops name=\"minimize_button_pressed\">\n");
  if (clearboxPrefs.buttonStyle != SIMPLE)
  {
    if (clearboxPrefs.buttonStyle == CLEAR_FRAME)
      g_string_append (xmlMinimizePressed, "  <include name=\"bg_button_pressed\"/>\n");
    else
      g_string_append (xmlMinimizePressed, "  <include name=\"bg_button\"/>\n");
  }
  g_string_append (xmlMinimizePressed, "  <line color=\"");
  g_string_append (xmlMinimizePressed, clearboxPrefs.colorButtonPressed);
  g_string_append (xmlMinimizePressed, "\" width=\"3\" x1=\"PrelightPad\" y1=\"height-ButtonPad-1\" x2=\"width-PrelightPad\" y2=\"height-ButtonPad-1\"/>\n");
  g_string_append (xmlMinimizePressed, "</draw_ops>\n\n");

  xmlMinimizePrelight = g_string_new ("<draw_ops name=\"minimize_button_prelight\">\n");
  if (clearboxPrefs.buttonStyle != SIMPLE)
  {
    if (clearboxPrefs.buttonStyle == CLEAR_FRAME)
      g_string_append (xmlMinimizePrelight, "  <include name=\"bg_button\"/>\n");
    else
      g_string_append (xmlMinimizePrelight, "  <include name=\"bg_button_prelight\"/>\n");
  }
  g_string_append (xmlMinimizePrelight, "  <line color=\"");
  g_string_append (xmlMinimizePrelight, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlMinimizePrelight, "\" width=\"3\" x1=\"PrelightPad\" y1=\"height-ButtonPad-1\" x2=\"width-PrelightPad\" y2=\"height-ButtonPad-1\"/>\n");
  g_string_append (xmlMinimizePrelight, "</draw_ops>\n\n");

  xmlMinimizeUnfocused = g_string_new ("<draw_ops name=\"minimize_button_unfocused\">\n");
  if (clearboxPrefs.buttonStyle != SIMPLE)
    g_string_append (xmlMinimizeUnfocused, "  <include name=\"bg_button\"/>\n");
  g_string_append (xmlMinimizeUnfocused, "  <line color=\"");
  g_string_append (xmlMinimizeUnfocused, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlMinimizeUnfocused, "\" width=\"3\" x1=\"ButtonPad\" y1=\"height-ButtonPad-1\" x2=\"width-ButtonPad\" y2=\"height-ButtonPad-1\"/>\n");
  g_string_append (xmlMinimizeUnfocused, "</draw_ops>\n\n");

  xmlMinimizeUnfocusedPrelight = g_string_new ("<draw_ops name=\"minimize_button_unfocused_prelight\">\n");
  if (clearboxPrefs.buttonStyle != SIMPLE)
  {
    if (clearboxPrefs.buttonStyle == CLEAR_FRAME)
      g_string_append (xmlMinimizeUnfocusedPrelight, "  <include name=\"bg_button\"/>\n");
    else
      g_string_append (xmlMinimizeUnfocusedPrelight, "  <include name=\"bg_button_prelight\"/>\n");
  }
  g_string_append (xmlMinimizeUnfocusedPrelight, "  <line color=\"");
  g_string_append (xmlMinimizeUnfocusedPrelight, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlMinimizeUnfocusedPrelight, "\" width=\"3\" x1=\"PrelightPad\" y1=\"height-ButtonPad-1\" x2=\"width-PrelightPad\" y2=\"height-ButtonPad-1\"/>\n");
  g_string_append (xmlMinimizeUnfocusedPrelight, "</draw_ops>\n\n");

  xmlMaximizeNormal = g_string_new ("<draw_ops name=\"maximize_button\">\n");
  if (clearboxPrefs.buttonStyle != SIMPLE)
    g_string_append (xmlMaximizeNormal, "  <include name=\"bg_button\"/>\n");
  g_string_append (xmlMaximizeNormal, "  <rectangle color=\"");
  g_string_append (xmlMaximizeNormal, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlMaximizeNormal, "\" x=\"ButtonPad-1\" y=\"ButtonPad-1\" width=\"width-ButtonPad*2+1\" height=\"height-ButtonPad*2+1\"/>\n");
  g_string_append (xmlMaximizeNormal, "  <line color=\"");
  g_string_append (xmlMaximizeNormal, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlMaximizeNormal, "\" width=\"1\" x1=\"ButtonPad-1\" y1=\"ButtonPad\" x2=\"width-ButtonPad+1\" y2=\"ButtonPad\"/>\n");
  g_string_append (xmlMaximizeNormal, "</draw_ops>\n\n");

  xmlMaximizePressed = g_string_new ("<draw_ops name=\"maximize_button_pressed\">\n");
  if (clearboxPrefs.buttonStyle != SIMPLE)
  {
    if (clearboxPrefs.buttonStyle == CLEAR_FRAME)
      g_string_append (xmlMaximizePressed, "  <include name=\"bg_button_pressed\"/>\n");
    else
      g_string_append (xmlMaximizePressed, "  <include name=\"bg_button\"/>\n");
  }
  g_string_append (xmlMaximizePressed, "  <rectangle color=\"");
  g_string_append (xmlMaximizePressed, clearboxPrefs.colorButtonPressed);
  g_string_append (xmlMaximizePressed, "\" x=\"PrelightPad-1\" y=\"PrelightPad-1\" width=\"width-PrelightPad*2+1\" height=\"height-PrelightPad*2+1\"/>\n");
  g_string_append (xmlMaximizePressed, "  <line color=\"");
  g_string_append (xmlMaximizePressed, clearboxPrefs.colorButtonPressed);
  g_string_append (xmlMaximizePressed, "\" width=\"1\" x1=\"PrelightPad-1\" y1=\"PrelightPad\" x2=\"width-PrelightPad+1\" y2=\"PrelightPad\"/>\n");
  g_string_append (xmlMaximizePressed, "</draw_ops>\n\n");

  xmlMaximizePrelight = g_string_new ("<draw_ops name=\"maximize_button_prelight\">\n");
  if (clearboxPrefs.buttonStyle != SIMPLE)
  {
    if (clearboxPrefs.buttonStyle == CLEAR_FRAME)
      g_string_append (xmlMaximizePrelight, "  <include name=\"bg_button\"/>\n");
    else
      g_string_append (xmlMaximizePrelight, "  <include name=\"bg_button_prelight\"/>\n");
  }
  g_string_append (xmlMaximizePrelight, "  <rectangle color=\"");
  g_string_append (xmlMaximizePrelight, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlMaximizePrelight, "\" x=\"PrelightPad-1\" y=\"PrelightPad-1\" width=\"width-PrelightPad*2+1\" height=\"height-PrelightPad*2+1\"/>\n");
  g_string_append (xmlMaximizePrelight, "  <line color=\"");
  g_string_append (xmlMaximizePrelight, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlMaximizePrelight, "\" width=\"1\" x1=\"PrelightPad-1\" y1=\"PrelightPad\" x2=\"width-PrelightPad+1\" y2=\"PrelightPad\"/>\n");
  g_string_append (xmlMaximizePrelight, "</draw_ops>\n\n");

  xmlMaximizeUnfocused = g_string_new ("<draw_ops name=\"maximize_button_unfocused\">\n");
  if (clearboxPrefs.buttonStyle != SIMPLE)
    g_string_append (xmlMaximizeUnfocused, "  <include name=\"bg_button\"/>\n");
  g_string_append (xmlMaximizeUnfocused, "  <rectangle color=\"");
  g_string_append (xmlMaximizeUnfocused, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlMaximizeUnfocused, "\" x=\"ButtonPad-1\" y=\"ButtonPad-1\" width=\"width-ButtonPad*2+1\" height=\"height-ButtonPad*2+1\"/>\n");
  g_string_append (xmlMaximizeUnfocused, "  <line color=\"");
  g_string_append (xmlMaximizeUnfocused, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlMaximizeUnfocused, "\" width=\"1\" x1=\"ButtonPad-1\" y1=\"ButtonPad\" x2=\"width-ButtonPad+1\" y2=\"ButtonPad\"/>\n");
  g_string_append (xmlMaximizeUnfocused, "</draw_ops>\n\n");

  xmlMaximizeUnfocusedPrelight = g_string_new ("<draw_ops name=\"maximize_button_unfocused_prelight\">\n");
  if (clearboxPrefs.buttonStyle != SIMPLE)
  {
    if (clearboxPrefs.buttonStyle == CLEAR_FRAME)
      g_string_append (xmlMaximizeUnfocusedPrelight, "  <include name=\"bg_button\"/>\n");
    else
      g_string_append (xmlMaximizeUnfocusedPrelight, "  <include name=\"bg_button_prelight\"/>\n");
  }
  g_string_append (xmlMaximizeUnfocusedPrelight, "  <rectangle color=\"");
  g_string_append (xmlMaximizeUnfocusedPrelight, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlMaximizeUnfocusedPrelight, "\" x=\"PrelightPad-1\" y=\"PrelightPad-1\" width=\"width-PrelightPad*2+1\" height=\"height-PrelightPad*2+1\"/>\n");
  g_string_append (xmlMaximizeUnfocusedPrelight, "  <line color=\"");
  g_string_append (xmlMaximizeUnfocusedPrelight, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlMaximizeUnfocusedPrelight, "\" width=\"1\" x1=\"PrelightPad-1\" y1=\"PrelightPad\" x2=\"width-PrelightPad+1\" y2=\"PrelightPad\"/>\n");
  g_string_append (xmlMaximizeUnfocusedPrelight, "</draw_ops>\n\n");

  xmlRestoreNormal = g_string_new ("<draw_ops name=\"restore_button\">\n");
  if (clearboxPrefs.buttonStyle != SIMPLE)
    g_string_append (xmlRestoreNormal, "  <include name=\"bg_button\"/>\n");
  g_string_append (xmlRestoreNormal, "  <rectangle color=\"");
  g_string_append (xmlRestoreNormal, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlRestoreNormal, "\" x=\"ButtonPad-1\" y=\"ButtonPad+2\" width=\"width-ButtonPad*2-1\" height=\"height-ButtonPad*2-2\"/>\n");
  g_string_append (xmlRestoreNormal, "  <line color=\"");
  g_string_append (xmlRestoreNormal, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlRestoreNormal, "\" width=\"1\" x1=\"ButtonPad-1\" y1=\"ButtonPad+3\" x2=\"width-ButtonPad-1\" y2=\"ButtonPad+3\"/>\n");
  g_string_append (xmlRestoreNormal, "  <line color=\"");
  g_string_append (xmlRestoreNormal, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlRestoreNormal, "\" width=\"2\" x1=\"ButtonPad+1\" y1=\"ButtonPad\" x2=\"width-ButtonPad+1\" y2=\"ButtonPad\"/>\n");
  g_string_append (xmlRestoreNormal, "  <line color=\"");
  g_string_append (xmlRestoreNormal, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlRestoreNormal, "\" width=\"1\" x1=\"ButtonPad+1\" y1=\"ButtonPad-1\" x2=\"ButtonPad+1\" y2=\"ButtonPad+3\"/>\n");
  g_string_append (xmlRestoreNormal, "  <line color=\"");
  g_string_append (xmlRestoreNormal, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlRestoreNormal, "\" width=\"1\" x1=\"width-ButtonPad\" y1=\"ButtonPad-1\" x2=\"width-ButtonPad\" y2=\"height-ButtonPad-1\"/>\n");
  g_string_append (xmlRestoreNormal, "  <line color=\"");
  g_string_append (xmlRestoreNormal, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlRestoreNormal, "\" width=\"1\" x1=\"width-ButtonPad-2\" y1=\"height-ButtonPad-2\" x2=\"width-ButtonPad+1\" y2=\"height-ButtonPad-2\"/>\n");
  g_string_append (xmlRestoreNormal, "</draw_ops>\n\n");

  xmlRestorePressed = g_string_new ("<draw_ops name=\"restore_button_pressed\">\n");
  if (clearboxPrefs.buttonStyle != SIMPLE)
  {
    if (clearboxPrefs.buttonStyle == CLEAR_FRAME)
      g_string_append (xmlRestorePressed, "  <include name=\"bg_button_pressed\"/>\n");
    else
      g_string_append (xmlRestorePressed, "  <include name=\"bg_button\"/>\n");
  }
  g_string_append (xmlRestorePressed, "  <rectangle color=\"");
  g_string_append (xmlRestorePressed, clearboxPrefs.colorButtonPressed);
  g_string_append (xmlRestorePressed, "\" x=\"PrelightPad-1\" y=\"PrelightPad+2\" width=\"width-PrelightPad*2-1\" height=\"height-PrelightPad*2-2\"/>\n");
  g_string_append (xmlRestorePressed, "  <line color=\"");
  g_string_append (xmlRestorePressed, clearboxPrefs.colorButtonPressed);
  g_string_append (xmlRestorePressed, "\" width=\"1\" x1=\"PrelightPad-1\" y1=\"PrelightPad+3\" x2=\"width-PrelightPad-1\" y2=\"PrelightPad+3\"/>\n");
  g_string_append (xmlRestorePressed, "  <line color=\"");
  g_string_append (xmlRestorePressed, clearboxPrefs.colorButtonPressed);
  g_string_append (xmlRestorePressed, "\" width=\"2\" x1=\"PrelightPad+1\" y1=\"PrelightPad\" x2=\"width-PrelightPad+1\" y2=\"PrelightPad\"/>\n");
  g_string_append (xmlRestorePressed, "  <line color=\"");
  g_string_append (xmlRestorePressed, clearboxPrefs.colorButtonPressed);
  g_string_append (xmlRestorePressed, "\" width=\"1\" x1=\"PrelightPad+1\" y1=\"PrelightPad-1\" x2=\"PrelightPad+1\" y2=\"PrelightPad+3\"/>\n");
  g_string_append (xmlRestorePressed, "  <line color=\"");
  g_string_append (xmlRestorePressed, clearboxPrefs.colorButtonPressed);
  g_string_append (xmlRestorePressed, "\" width=\"1\" x1=\"width-PrelightPad\" y1=\"PrelightPad-1\" x2=\"width-PrelightPad\" y2=\"height-PrelightPad-1\"/>\n");
  g_string_append (xmlRestorePressed, "  <line color=\"");
  g_string_append (xmlRestorePressed, clearboxPrefs.colorButtonPressed);
  g_string_append (xmlRestorePressed, "\" width=\"1\" x1=\"width-PrelightPad-2\" y1=\"height-PrelightPad-2\" x2=\"width-PrelightPad+1\" y2=\"height-PrelightPad-2\"/>\n");
  g_string_append (xmlRestorePressed, "</draw_ops>\n\n");

  xmlRestorePrelight = g_string_new ("<draw_ops name=\"restore_button_prelight\">\n");
  if (clearboxPrefs.buttonStyle != SIMPLE)
  {
    if (clearboxPrefs.buttonStyle == CLEAR_FRAME)
      g_string_append (xmlRestorePrelight, "  <include name=\"bg_button\"/>\n");
    else
      g_string_append (xmlRestorePrelight, "  <include name=\"bg_button_prelight\"/>\n");
  }
  g_string_append (xmlRestorePrelight, "  <rectangle color=\"");
  g_string_append (xmlRestorePrelight, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlRestorePrelight, "\" x=\"PrelightPad-1\" y=\"PrelightPad+2\" width=\"width-PrelightPad*2-1\" height=\"height-PrelightPad*2-2\"/>\n");
  g_string_append (xmlRestorePrelight, "  <line color=\"");
  g_string_append (xmlRestorePrelight, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlRestorePrelight, "\" width=\"1\" x1=\"PrelightPad-1\" y1=\"PrelightPad+3\" x2=\"width-PrelightPad-1\" y2=\"PrelightPad+3\"/>\n");
  g_string_append (xmlRestorePrelight, "  <line color=\"");
  g_string_append (xmlRestorePrelight, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlRestorePrelight, "\" width=\"2\" x1=\"PrelightPad+1\" y1=\"PrelightPad\" x2=\"width-PrelightPad+1\" y2=\"PrelightPad\"/>\n");
  g_string_append (xmlRestorePrelight, "  <line color=\"");
  g_string_append (xmlRestorePrelight, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlRestorePrelight, "\" width=\"1\" x1=\"PrelightPad+1\" y1=\"PrelightPad-1\" x2=\"PrelightPad+1\" y2=\"PrelightPad+3\"/>\n");
  g_string_append (xmlRestorePrelight, "  <line color=\"");
  g_string_append (xmlRestorePrelight, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlRestorePrelight, "\" width=\"1\" x1=\"width-PrelightPad\" y1=\"PrelightPad-1\" x2=\"width-PrelightPad\" y2=\"height-PrelightPad-1\"/>\n");
  g_string_append (xmlRestorePrelight, "  <line color=\"");
  g_string_append (xmlRestorePrelight, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlRestorePrelight, "\" width=\"1\" x1=\"width-PrelightPad-2\" y1=\"height-PrelightPad-2\" x2=\"width-PrelightPad+1\" y2=\"height-PrelightPad-2\"/>\n");
  g_string_append (xmlRestorePrelight, "</draw_ops>\n\n");

  xmlRestoreUnfocused = g_string_new ("<draw_ops name=\"restore_button_unfocused\">\n");
  if (clearboxPrefs.buttonStyle != SIMPLE)
    g_string_append (xmlRestoreUnfocused, "  <include name=\"bg_button\"/>\n");
  g_string_append (xmlRestoreUnfocused, "  <rectangle color=\"");
  g_string_append (xmlRestoreUnfocused, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlRestoreUnfocused, "\" x=\"ButtonPad-1\" y=\"ButtonPad+2\" width=\"width-ButtonPad*2-1\" height=\"height-ButtonPad*2-2\"/>\n");
  g_string_append (xmlRestoreUnfocused, "  <line color=\"");
  g_string_append (xmlRestoreUnfocused, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlRestoreUnfocused, "\" width=\"1\" x1=\"ButtonPad-1\" y1=\"ButtonPad+3\" x2=\"width-ButtonPad-1\" y2=\"ButtonPad+3\"/>\n");
  g_string_append (xmlRestoreUnfocused, "  <line color=\"");
  g_string_append (xmlRestoreUnfocused, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlRestoreUnfocused, "\" width=\"2\" x1=\"ButtonPad+1\" y1=\"ButtonPad\" x2=\"width-ButtonPad+1\" y2=\"ButtonPad\"/>\n");
  g_string_append (xmlRestoreUnfocused, "  <line color=\"");
  g_string_append (xmlRestoreUnfocused, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlRestoreUnfocused, "\" width=\"1\" x1=\"ButtonPad+1\" y1=\"ButtonPad-1\" x2=\"ButtonPad+1\" y2=\"ButtonPad+3\"/>\n");
  g_string_append (xmlRestoreUnfocused, "  <line color=\"");
  g_string_append (xmlRestoreUnfocused, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlRestoreUnfocused, "\" width=\"1\" x1=\"width-ButtonPad\" y1=\"ButtonPad-1\" x2=\"width-ButtonPad\" y2=\"height-ButtonPad-1\"/>\n");
  g_string_append (xmlRestoreUnfocused, "  <line color=\"");
  g_string_append (xmlRestoreUnfocused, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlRestoreUnfocused, "\" width=\"1\" x1=\"width-ButtonPad-2\" y1=\"height-ButtonPad-2\" x2=\"width-ButtonPad+1\" y2=\"height-ButtonPad-2\"/>\n");
  g_string_append (xmlRestoreUnfocused, "</draw_ops>\n\n");

  xmlRestoreUnfocusedPrelight = g_string_new ("<draw_ops name=\"restore_button_unfocused_prelight\">\n");
  if (clearboxPrefs.buttonStyle != SIMPLE)
  {
    if (clearboxPrefs.buttonStyle == CLEAR_FRAME)
      g_string_append (xmlRestoreUnfocusedPrelight, "  <include name=\"bg_button\"/>\n");
    else
      g_string_append (xmlRestoreUnfocusedPrelight, "  <include name=\"bg_button_prelight\"/>\n");
  }
  g_string_append (xmlRestoreUnfocusedPrelight, "  <rectangle color=\"");
  g_string_append (xmlRestoreUnfocusedPrelight, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlRestoreUnfocusedPrelight, "\" x=\"PrelightPad-1\" y=\"PrelightPad+2\" width=\"width-PrelightPad*2-1\" height=\"height-PrelightPad*2-2\"/>\n");
  g_string_append (xmlRestoreUnfocusedPrelight, "  <line color=\"");
  g_string_append (xmlRestoreUnfocusedPrelight, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlRestoreUnfocusedPrelight, "\" width=\"1\" x1=\"PrelightPad-1\" y1=\"PrelightPad+3\" x2=\"width-PrelightPad-1\" y2=\"PrelightPad+3\"/>\n");
  g_string_append (xmlRestoreUnfocusedPrelight, "  <line color=\"");
  g_string_append (xmlRestoreUnfocusedPrelight, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlRestoreUnfocusedPrelight, "\" width=\"2\" x1=\"PrelightPad+1\" y1=\"PrelightPad\" x2=\"width-PrelightPad+1\" y2=\"PrelightPad\"/>\n");
  g_string_append (xmlRestoreUnfocusedPrelight, "  <line color=\"");
  g_string_append (xmlRestoreUnfocusedPrelight, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlRestoreUnfocusedPrelight, "\" width=\"1\" x1=\"PrelightPad+1\" y1=\"PrelightPad-1\" x2=\"PrelightPad+1\" y2=\"PrelightPad+3\"/>\n");
  g_string_append (xmlRestoreUnfocusedPrelight, "  <line color=\"");
  g_string_append (xmlRestoreUnfocusedPrelight, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlRestoreUnfocusedPrelight, "\" width=\"1\" x1=\"width-PrelightPad\" y1=\"PrelightPad-1\" x2=\"width-PrelightPad\" y2=\"height-PrelightPad-1\"/>\n");
  g_string_append (xmlRestoreUnfocusedPrelight, "  <line color=\"");
  g_string_append (xmlRestoreUnfocusedPrelight, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlRestoreUnfocusedPrelight, "\" width=\"1\" x1=\"width-PrelightPad-2\" y1=\"height-PrelightPad-2\" x2=\"width-PrelightPad+1\" y2=\"height-PrelightPad-2\"/>\n");
  g_string_append (xmlRestoreUnfocusedPrelight, "</draw_ops>\n\n");

  xmlCloseNormal = g_string_new ("<draw_ops name=\"close_button\">\n");
  if (clearboxPrefs.buttonStyle != SIMPLE)
    g_string_append (xmlCloseNormal, "  <include name=\"bg_button\"/>\n");
  g_string_append (xmlCloseNormal, "  <line color=\"");
  g_string_append (xmlCloseNormal, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlCloseNormal, "\" width=\"2\" x1=\"ButtonPad-1\" y1=\"ButtonPad-1\" x2=\"width-ButtonPad\" y2=\"height-ButtonPad\"/>\n");
  g_string_append (xmlCloseNormal, "  <line color=\"");
  g_string_append (xmlCloseNormal, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlCloseNormal, "\" width=\"1\" x1=\"ButtonPad-1\" y1=\"ButtonPad-1\" x2=\"width-ButtonPad+1\" y2=\"height-ButtonPad+1\"/>\n");
  g_string_append (xmlCloseNormal, "  <line color=\"");
  g_string_append (xmlCloseNormal, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlCloseNormal, "\" width=\"2\" x1=\"ButtonPad-1\" y1=\"height-ButtonPad\" x2=\"width-ButtonPad\" y2=\"ButtonPad-1\"/>\n");
  g_string_append (xmlCloseNormal, "  <line color=\"");
  g_string_append (xmlCloseNormal, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlCloseNormal, "\" width=\"1\" x1=\"ButtonPad-1\" y1=\"height-ButtonPad\" x2=\"width-ButtonPad+1\" y2=\"ButtonPad-2\"/>\n");
  g_string_append (xmlCloseNormal, "</draw_ops>\n\n");

  xmlClosePressed = g_string_new ("<draw_ops name=\"close_button_pressed\">\n");
  if (clearboxPrefs.buttonStyle != SIMPLE)
  {
    if (clearboxPrefs.buttonStyle == CLEAR_FRAME)
      g_string_append (xmlClosePressed, "  <include name=\"bg_button_pressed\"/>\n");
    else
      g_string_append (xmlClosePressed, "  <include name=\"bg_button\"/>\n");
  }
  g_string_append (xmlClosePressed, "  <line color=\"");
  g_string_append (xmlClosePressed, clearboxPrefs.colorButtonPressed);
  g_string_append (xmlClosePressed, "\" width=\"2\" x1=\"PrelightPad-1\" y1=\"PrelightPad-1\" x2=\"width-PrelightPad\" y2=\"height-PrelightPad\"/>\n");
  g_string_append (xmlClosePressed, "  <line color=\"");
  g_string_append (xmlClosePressed, clearboxPrefs.colorButtonPressed);
  g_string_append (xmlClosePressed, "\" width=\"1\" x1=\"PrelightPad-1\" y1=\"PrelightPad-1\" x2=\"width-PrelightPad+1\" y2=\"height-PrelightPad+1\"/>\n");
  g_string_append (xmlClosePressed, "  <line color=\"");
  g_string_append (xmlClosePressed, clearboxPrefs.colorButtonPressed);
  g_string_append (xmlClosePressed, "\" width=\"2\" x1=\"PrelightPad-1\" y1=\"height-PrelightPad\" x2=\"width-PrelightPad\" y2=\"PrelightPad-1\"/>\n");
  g_string_append (xmlClosePressed, "  <line color=\"");
  g_string_append (xmlClosePressed, clearboxPrefs.colorButtonPressed);
  g_string_append (xmlClosePressed, "\" width=\"1\" x1=\"PrelightPad-1\" y1=\"height-PrelightPad\" x2=\"width-PrelightPad+1\" y2=\"PrelightPad-2\"/>\n");
  g_string_append (xmlClosePressed, "</draw_ops>\n\n");

  xmlClosePrelight = g_string_new ("<draw_ops name=\"close_button_prelight\">\n");
  if (clearboxPrefs.buttonStyle != SIMPLE)
  {
    if (clearboxPrefs.buttonStyle == CLEAR_FRAME)
      g_string_append (xmlClosePrelight, "  <include name=\"bg_button\"/>\n");
    else
      g_string_append (xmlClosePrelight, "  <include name=\"bg_button_prelight\"/>\n");
  }
  g_string_append (xmlClosePrelight, "  <line color=\"");
  g_string_append (xmlClosePrelight, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlClosePrelight, "\" width=\"2\" x1=\"PrelightPad-1\" y1=\"PrelightPad-1\" x2=\"width-PrelightPad\" y2=\"height-PrelightPad\"/>\n");
  g_string_append (xmlClosePrelight, "  <line color=\"");
  g_string_append (xmlClosePrelight, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlClosePrelight, "\" width=\"1\" x1=\"PrelightPad-1\" y1=\"PrelightPad-1\" x2=\"width-PrelightPad+1\" y2=\"height-PrelightPad+1\"/>\n");
  g_string_append (xmlClosePrelight, "  <line color=\"");
  g_string_append (xmlClosePrelight, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlClosePrelight, "\" width=\"2\" x1=\"PrelightPad-1\" y1=\"height-PrelightPad\" x2=\"width-PrelightPad\" y2=\"PrelightPad-1\"/>\n");
  g_string_append (xmlClosePrelight, "  <line color=\"");
  g_string_append (xmlClosePrelight, clearboxPrefs.colorButtonFocused);
  g_string_append (xmlClosePrelight, "\" width=\"1\" x1=\"PrelightPad-1\" y1=\"height-PrelightPad\" x2=\"width-PrelightPad+1\" y2=\"PrelightPad-2\"/>\n");
  g_string_append (xmlClosePrelight, "</draw_ops>\n\n");

  xmlCloseUnfocused = g_string_new ("<draw_ops name=\"close_button_unfocused\">\n");
  if (clearboxPrefs.buttonStyle != SIMPLE)
    g_string_append (xmlCloseUnfocused, "  <include name=\"bg_button\"/>\n");
  g_string_append (xmlCloseUnfocused, "  <line color=\"");
  g_string_append (xmlCloseUnfocused, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlCloseUnfocused, "\" width=\"2\" x1=\"ButtonPad-1\" y1=\"ButtonPad-1\" x2=\"width-ButtonPad\" y2=\"height-ButtonPad\"/>\n");
  g_string_append (xmlCloseUnfocused, "  <line color=\"");
  g_string_append (xmlCloseUnfocused, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlCloseUnfocused, "\" width=\"1\" x1=\"ButtonPad-1\" y1=\"ButtonPad-1\" x2=\"width-ButtonPad+1\" y2=\"height-ButtonPad+1\"/>\n");
  g_string_append (xmlCloseUnfocused, "  <line color=\"");
  g_string_append (xmlCloseUnfocused, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlCloseUnfocused, "\" width=\"2\" x1=\"ButtonPad-1\" y1=\"height-ButtonPad\" x2=\"width-ButtonPad\" y2=\"ButtonPad-1\"/>\n");
  g_string_append (xmlCloseUnfocused, "  <line color=\"");
  g_string_append (xmlCloseUnfocused, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlCloseUnfocused, "\" width=\"1\" x1=\"ButtonPad-1\" y1=\"height-ButtonPad\" x2=\"width-ButtonPad+1\" y2=\"ButtonPad-2\"/>\n");
  g_string_append (xmlCloseUnfocused, "</draw_ops>\n\n");

  xmlCloseUnfocusedPrelight = g_string_new ("<draw_ops name=\"close_button_unfocused_prelight\">\n");
  if (clearboxPrefs.buttonStyle != SIMPLE)
  {
    if (clearboxPrefs.buttonStyle == CLEAR_FRAME)
      g_string_append (xmlCloseUnfocusedPrelight, "  <include name=\"bg_button\"/>\n");
    else
      g_string_append (xmlCloseUnfocusedPrelight, "  <include name=\"bg_button_prelight\"/>\n");
  }
  g_string_append (xmlCloseUnfocusedPrelight, "  <line color=\"");
  g_string_append (xmlCloseUnfocusedPrelight, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlCloseUnfocusedPrelight, "\" width=\"2\" x1=\"PrelightPad-1\" y1=\"PrelightPad-1\" x2=\"width-PrelightPad\" y2=\"height-PrelightPad\"/>\n");
  g_string_append (xmlCloseUnfocusedPrelight, "  <line color=\"");
  g_string_append (xmlCloseUnfocusedPrelight, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlCloseUnfocusedPrelight, "\" width=\"1\" x1=\"PrelightPad-1\" y1=\"PrelightPad-1\" x2=\"width-PrelightPad+1\" y2=\"height-PrelightPad+1\"/>\n");
  g_string_append (xmlCloseUnfocusedPrelight, "  <line color=\"");
  g_string_append (xmlCloseUnfocusedPrelight, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlCloseUnfocusedPrelight, "\" width=\"2\" x1=\"PrelightPad-1\" y1=\"height-PrelightPad\" x2=\"width-PrelightPad\" y2=\"PrelightPad-1\"/>\n");
  g_string_append (xmlCloseUnfocusedPrelight, "  <line color=\"");
  g_string_append (xmlCloseUnfocusedPrelight, clearboxPrefs.colorButtonUnfocused);
  g_string_append (xmlCloseUnfocusedPrelight, "\" width=\"1\" x1=\"PrelightPad-1\" y1=\"height-PrelightPad\" x2=\"width-PrelightPad+1\" y2=\"PrelightPad-2\"/>\n");
  g_string_append (xmlCloseUnfocusedPrelight, "</draw_ops>\n\n");

  g_io_channel_write_chars (xmlFile, xmlPad->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlFrame->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlFramePrelight->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlFramePressed->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlMenuNormal->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlMenuPressed->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlMenuPrelight->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlMenuUnfocused->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlMenuUnfocusedPrelight->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlMinimizeNormal->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlMinimizePressed->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlMinimizePrelight->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlMinimizeUnfocused->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlMinimizeUnfocusedPrelight->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlMaximizeNormal->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlMaximizePressed->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlMaximizePrelight->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlMaximizeUnfocused->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlMaximizeUnfocusedPrelight->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlRestoreNormal->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlRestorePressed->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlRestorePrelight->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlRestoreUnfocused->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlRestoreUnfocusedPrelight->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlCloseNormal->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlClosePressed->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlClosePrelight->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlCloseUnfocused->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlCloseUnfocusedPrelight->str, -1, &bytes, &error);

  g_string_free (xmlPad, TRUE);
  g_string_free (xmlFrame, TRUE);
  g_string_free (xmlFramePrelight, TRUE);
  g_string_free (xmlFramePressed, TRUE);
  g_string_free (xmlMenuNormal, TRUE);
  g_string_free (xmlMenuPressed, TRUE);
  g_string_free (xmlMenuPrelight, TRUE);
  g_string_free (xmlMenuUnfocused, TRUE);
  g_string_free (xmlMenuUnfocusedPrelight, TRUE);
  g_string_free (xmlMinimizeNormal, TRUE);
  g_string_free (xmlMinimizePressed, TRUE);
  g_string_free (xmlMinimizePrelight, TRUE);
  g_string_free (xmlMinimizeUnfocused, TRUE);
  g_string_free (xmlMinimizeUnfocusedPrelight, TRUE);
  g_string_free (xmlMaximizeNormal, TRUE);
  g_string_free (xmlMaximizePressed, TRUE);
  g_string_free (xmlMaximizePrelight, TRUE);
  g_string_free (xmlMaximizeUnfocused, TRUE);
  g_string_free (xmlMaximizeUnfocusedPrelight, TRUE);
  g_string_free (xmlRestoreNormal, TRUE);
  g_string_free (xmlRestorePressed, TRUE);
  g_string_free (xmlRestorePrelight, TRUE);
  g_string_free (xmlRestoreUnfocused, TRUE);
  g_string_free (xmlRestoreUnfocusedPrelight, TRUE);
  g_string_free (xmlCloseNormal, TRUE);
  g_string_free (xmlClosePressed, TRUE);
  g_string_free (xmlClosePrelight, TRUE);
  g_string_free (xmlCloseUnfocused, TRUE);
  g_string_free (xmlCloseUnfocusedPrelight, TRUE);
}

/* Establece y escribe el dibujado del título del fichero xml */

void set_xml_title (GIOChannel *xmlFile)
{
  gsize bytes;
  GError *error = NULL;
  GString *xmlTitleFocused;
  GString *xmlTitleUnfocused;
  
  xmlTitleFocused = g_string_new ("<draw_ops name=\"title_focused\">\n");
  if (clearboxPrefs.titleShadow)
  {
    g_string_append (xmlTitleFocused, "  <title color=\"");
    g_string_append (xmlTitleFocused, colorShadow->str);
    g_string_append (xmlTitleFocused, "\" x=\"5");
    if (clearboxPrefs.titlePosition == CENTER)
      g_string_append (xmlTitleFocused, " `max` (width-title_width)/2+1");
    g_string_append (xmlTitleFocused, "\" y=\"1 `max` ((height-title_height)/2)+1\"/>\n");
  }
  g_string_append (xmlTitleFocused, "  <title color=\"");
  g_string_append (xmlTitleFocused, clearboxPrefs.colorTitleFocused);
  g_string_append (xmlTitleFocused, "\" x=\"4");
  if (clearboxPrefs.titlePosition == CENTER)
    g_string_append (xmlTitleFocused, " `max` (width-title_width)/2");
  g_string_append (xmlTitleFocused, "\" y=\"0 `max` ((height-title_height)/2)\"/>\n");
  g_string_append (xmlTitleFocused, "</draw_ops>\n\n");

  xmlTitleUnfocused = g_string_new ("<draw_ops name=\"title_unfocused\">\n");
  g_string_append (xmlTitleUnfocused, "  <title color=\"");
  g_string_append (xmlTitleUnfocused, clearboxPrefs.colorTitleUnfocused);
  g_string_append (xmlTitleUnfocused, "\" x=\"4");
  if (clearboxPrefs.titlePosition == CENTER)
    g_string_append (xmlTitleUnfocused, " `max` (width-title_width)/2");
  g_string_append (xmlTitleUnfocused, "\" y=\"0 `max` ((height-title_height)/2)\"/>\n");
  g_string_append (xmlTitleUnfocused, "</draw_ops>\n\n");

  g_io_channel_write_chars (xmlFile, xmlTitleFocused->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlTitleUnfocused->str, -1, &bytes, &error);

  g_string_free (xmlTitleFocused, TRUE);
  g_string_free (xmlTitleUnfocused, TRUE);
}

/* Establece y escribe los estilos del fichero xml */

void set_xml_styles (GIOChannel *xmlFile)
{
  gsize bytes;
  GError *error = NULL;
  GString *xmlNormalFocused;
  GString *xmlNormalShadedFocused;
  GString *xmlNormalUnfocused;
  GString *xmlNormalShadedUnfocused;
  GString *xmlMaximizedFocused;
  GString *xmlMaximizedShadedFocused;
  GString *xmlMaximizedUnfocused;
  GString *xmlMaximizedShadedUnfocused;
  GString *xmlUtilityFocused;
  GString *xmlUtilityUnfocused;
  GString *xmlBorder;

  xmlNormalFocused = g_string_new ("<frame_style name=\"normal_focused\" geometry=\"normal\">\n");
  g_string_append (xmlNormalFocused, "  <piece position=\"entire_background\" draw_ops=\"bg_window_borders\"/>\n");
  g_string_append (xmlNormalFocused, "  <piece position=\"title\" draw_ops=\"title_focused\"/>\n");
  g_string_append (xmlNormalFocused, "  <piece position=\"left_titlebar_edge\" draw_ops=\"bg_left_title\"/>\n");
  g_string_append (xmlNormalFocused, "  <piece position=\"right_titlebar_edge\" draw_ops=\"bg_right_title\"/>\n");
  g_string_append (xmlNormalFocused, "  <piece position=\"bottom_titlebar_edge\" draw_ops=\"bg_bottom_title\"/>\n");
  g_string_append (xmlNormalFocused, "  <button function=\"close\" state=\"normal\" draw_ops=\"close_button\"/>\n");
  g_string_append (xmlNormalFocused, "  <button function=\"close\" state=\"pressed\" draw_ops=\"close_button_pressed\"/>\n");
  g_string_append (xmlNormalFocused, "  <button function=\"close\" state=\"prelight\" draw_ops=\"close_button_prelight\"/>\n");
  g_string_append (xmlNormalFocused, "  <button function=\"minimize\" state=\"normal\" draw_ops=\"minimize_button\"/>\n");
  g_string_append (xmlNormalFocused, "  <button function=\"minimize\" state=\"pressed\" draw_ops=\"minimize_button_pressed\"/>\n");
  g_string_append (xmlNormalFocused, "  <button function=\"minimize\" state=\"prelight\" draw_ops=\"minimize_button_prelight\"/>\n");
  g_string_append (xmlNormalFocused, "  <button function=\"maximize\" state=\"normal\" draw_ops=\"maximize_button\"/>\n");
  g_string_append (xmlNormalFocused, "  <button function=\"maximize\" state=\"pressed\" draw_ops=\"maximize_button_pressed\"/>\n");
  g_string_append (xmlNormalFocused, "  <button function=\"maximize\" state=\"prelight\" draw_ops=\"maximize_button_prelight\"/>\n");
  g_string_append (xmlNormalFocused, "  <button function=\"menu\" state=\"normal\" draw_ops=\"menu_button\"/>\n");
  g_string_append (xmlNormalFocused, "  <button function=\"menu\" state=\"pressed\" draw_ops=\"menu_button_pressed\"/>\n");
  g_string_append (xmlNormalFocused, "  <button function=\"menu\" state=\"prelight\" draw_ops=\"menu_button_prelight\"/>\n");
  g_string_append (xmlNormalFocused, "</frame_style>\n\n");

  xmlNormalShadedFocused = g_string_new ("<frame_style name=\"normal_shaded_focused\" geometry=\"normal\" parent=\"normal_focused\">\n");
  g_string_append (xmlNormalShadedFocused, "  <piece position=\"entire_background\" draw_ops=\"bg_window_no_borders\"/>\n");
  g_string_append (xmlNormalShadedFocused, "  <piece position=\"left_titlebar_edge\" draw_ops=\"bg_left_title_shaded\"/>\n");
  g_string_append (xmlNormalShadedFocused, "  <piece position=\"right_titlebar_edge\" draw_ops=\"bg_right_title_shaded\"/>\n");
  g_string_append (xmlNormalShadedFocused, "</frame_style>\n\n");

  xmlNormalUnfocused = g_string_new ("<frame_style name=\"normal_unfocused\" geometry=\"normal\">\n");
  g_string_append (xmlNormalUnfocused, "  <piece position=\"entire_background\" draw_ops=\"bg_window_borders\"/>\n");
  g_string_append (xmlNormalUnfocused, "  <piece position=\"title\" draw_ops=\"title_unfocused\"/>\n");
  g_string_append (xmlNormalUnfocused, "  <piece position=\"left_titlebar_edge\" draw_ops=\"bg_left_title\"/>\n");
  g_string_append (xmlNormalUnfocused, "  <piece position=\"right_titlebar_edge\" draw_ops=\"bg_right_title\"/>\n");
  g_string_append (xmlNormalUnfocused, "  <piece position=\"bottom_titlebar_edge\" draw_ops=\"bg_bottom_title\"/>\n");
  g_string_append (xmlNormalUnfocused, "  <button function=\"close\" state=\"normal\" draw_ops=\"close_button_unfocused\"/>\n");
  g_string_append (xmlNormalUnfocused, "  <button function=\"close\" state=\"pressed\" draw_ops=\"close_button_pressed\"/>\n");
  g_string_append (xmlNormalUnfocused, "  <button function=\"close\" state=\"prelight\" draw_ops=\"close_button_unfocused_prelight\"/>\n");
  g_string_append (xmlNormalUnfocused, "  <button function=\"minimize\" state=\"normal\" draw_ops=\"minimize_button_unfocused\"/>\n");
  g_string_append (xmlNormalUnfocused, "  <button function=\"minimize\" state=\"pressed\" draw_ops=\"minimize_button_pressed\"/>\n");
  g_string_append (xmlNormalUnfocused, "  <button function=\"minimize\" state=\"prelight\" draw_ops=\"minimize_button_unfocused_prelight\"/>\n");
  g_string_append (xmlNormalUnfocused, "  <button function=\"maximize\" state=\"normal\" draw_ops=\"maximize_button_unfocused\"/>\n");
  g_string_append (xmlNormalUnfocused, "  <button function=\"maximize\" state=\"pressed\" draw_ops=\"maximize_button_pressed\"/>\n");
  g_string_append (xmlNormalUnfocused, "  <button function=\"maximize\" state=\"prelight\" draw_ops=\"maximize_button_unfocused_prelight\"/>\n");
  g_string_append (xmlNormalUnfocused, "  <button function=\"menu\" state=\"normal\" draw_ops=\"menu_button_unfocused\"/>\n");
  g_string_append (xmlNormalUnfocused, "  <button function=\"menu\" state=\"pressed\" draw_ops=\"menu_button_pressed\"/>\n");
  g_string_append (xmlNormalUnfocused, "  <button function=\"menu\" state=\"prelight\" draw_ops=\"menu_button_unfocused_prelight\"/>\n");
  g_string_append (xmlNormalUnfocused, "</frame_style>\n\n");

  xmlNormalShadedUnfocused = g_string_new ("<frame_style name=\"normal_shaded_unfocused\" geometry=\"normal\" parent=\"normal_unfocused\">\n");
  g_string_append (xmlNormalShadedUnfocused, "  <piece position=\"entire_background\" draw_ops=\"bg_window_no_borders\"/>\n");
  g_string_append (xmlNormalShadedUnfocused, "  <piece position=\"left_titlebar_edge\" draw_ops=\"bg_left_title_shaded\"/>\n");
  g_string_append (xmlNormalShadedUnfocused, "  <piece position=\"right_titlebar_edge\" draw_ops=\"bg_right_title_shaded\"/>\n");
  g_string_append (xmlNormalShadedUnfocused, "</frame_style>\n\n");

  xmlMaximizedFocused = g_string_new ("<frame_style name=\"maximized_focused\" geometry=\"no_borders\" parent=\"normal_focused\">\n");
  g_string_append (xmlMaximizedFocused, "  <piece position=\"entire_background\" draw_ops=\"bg_topbar_max\"/>\n");
  g_string_append (xmlMaximizedFocused, "  <piece position=\"left_titlebar_edge\" draw_ops=\"bg_blank\"/>\n");
  g_string_append (xmlMaximizedFocused, "  <piece position=\"right_titlebar_edge\" draw_ops=\"bg_blank\"/>\n");
  g_string_append (xmlMaximizedFocused, "  <piece position=\"bottom_titlebar_edge\" draw_ops=\"bg_bottom_title_no_borders\"/>\n");
  g_string_append (xmlMaximizedFocused, "  <button function=\"maximize\" state=\"normal\" draw_ops=\"restore_button\"/>\n");
  g_string_append (xmlMaximizedFocused, "  <button function=\"maximize\" state=\"pressed\" draw_ops=\"restore_button_pressed\"/>\n");
  g_string_append (xmlMaximizedFocused, "  <button function=\"maximize\" state=\"prelight\" draw_ops=\"restore_button_prelight\"/>\n");
  g_string_append (xmlMaximizedFocused, "</frame_style>\n\n");

  xmlMaximizedShadedFocused = g_string_new ("<frame_style name=\"maximized_shaded_focused\" geometry=\"no_borders\" parent=\"maximized_focused\">\n");
  g_string_append (xmlMaximizedShadedFocused, "  <piece position=\"bottom_titlebar_edge\" draw_ops=\"botton_outline\"/>\n");
  g_string_append (xmlMaximizedShadedFocused, "</frame_style>\n\n");

  xmlMaximizedUnfocused = g_string_new ("<frame_style name=\"maximized_unfocused\" geometry=\"no_borders\" parent=\"normal_unfocused\">\n");
  g_string_append (xmlMaximizedUnfocused, "  <piece position=\"entire_background\" draw_ops=\"bg_topbar_max\"/>\n");
  g_string_append (xmlMaximizedUnfocused, "  <piece position=\"left_titlebar_edge\" draw_ops=\"bg_blank\"/>\n");
  g_string_append (xmlMaximizedUnfocused, "  <piece position=\"right_titlebar_edge\" draw_ops=\"bg_blank\"/>\n");
  g_string_append (xmlMaximizedUnfocused, "  <piece position=\"bottom_titlebar_edge\" draw_ops=\"bg_bottom_title_no_borders\"/>\n");
  g_string_append (xmlMaximizedUnfocused, "  <button function=\"maximize\" state=\"normal\" draw_ops=\"restore_button_unfocused\"/>\n");
  g_string_append (xmlMaximizedUnfocused, "  <button function=\"maximize\" state=\"pressed\" draw_ops=\"restore_button_pressed\"/>\n");
  g_string_append (xmlMaximizedUnfocused, "  <button function=\"maximize\" state=\"prelight\" draw_ops=\"restore_button_unfocused_prelight\"/>\n");
  g_string_append (xmlMaximizedUnfocused, "</frame_style>\n\n");

  xmlMaximizedShadedUnfocused = g_string_new ("<frame_style name=\"maximized_shaded_unfocused\" geometry=\"no_borders\" parent=\"maximized_unfocused\">\n");
  g_string_append (xmlMaximizedShadedUnfocused, "  <piece position=\"bottom_titlebar_edge\" draw_ops=\"botton_outline\"/>\n");
  g_string_append (xmlMaximizedShadedUnfocused, "</frame_style>\n\n");

  xmlUtilityFocused = g_string_new ("<frame_style name=\"utility_focused\" geometry=\"utility\" parent=\"normal_focused\">\n");
  g_string_append (xmlUtilityFocused, "  <piece position=\"entire_background\" draw_ops=\"bg_window_no_borders\"/>\n");
  g_string_append (xmlUtilityFocused, "  <piece position=\"left_titlebar_edge\" draw_ops=\"bg_blank\"/>\n");
  g_string_append (xmlUtilityFocused, "  <piece position=\"right_titlebar_edge\" draw_ops=\"bg_blank\"/>\n");
  g_string_append (xmlUtilityFocused, "  <piece position=\"bottom_titlebar_edge\" draw_ops=\"bg_bottom_title_no_borders\"/>\n");
  g_string_append (xmlUtilityFocused, "</frame_style>\n\n");

  xmlUtilityUnfocused = g_string_new ("<frame_style name=\"utility_unfocused\" geometry=\"utility\" parent=\"normal_unfocused\">\n");
  g_string_append (xmlUtilityUnfocused, "  <piece position=\"entire_background\" draw_ops=\"bg_window_no_borders\"/>\n");
  g_string_append (xmlUtilityUnfocused, "  <piece position=\"left_titlebar_edge\" draw_ops=\"bg_blank\"/>\n");
  g_string_append (xmlUtilityUnfocused, "  <piece position=\"right_titlebar_edge\" draw_ops=\"bg_blank\"/>\n");
  g_string_append (xmlUtilityUnfocused, "  <piece position=\"bottom_titlebar_edge\" draw_ops=\"bg_bottom_title_no_borders\"/>\n");
  g_string_append (xmlUtilityUnfocused, "</frame_style>\n\n");

  xmlBorder = g_string_new ("<frame_style name=\"border\" geometry=\"border\" parent=\"normal_unfocused\">\n");
  g_string_append (xmlBorder, "  <piece position=\"entire_background\" draw_ops=\"outline\"/>\n");
  g_string_append (xmlBorder, "  <piece position=\"title\" draw_ops=\"bg_blank\"/>\n");
  g_string_append (xmlBorder, "</frame_style>\n\n");

  g_io_channel_write_chars (xmlFile, xmlNormalFocused->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlNormalShadedFocused->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlNormalUnfocused->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlNormalShadedUnfocused->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlMaximizedFocused->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlMaximizedShadedFocused->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlMaximizedUnfocused->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlMaximizedShadedUnfocused->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlUtilityFocused->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlUtilityUnfocused->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlBorder->str, -1, &bytes, &error);

  g_string_free (xmlNormalFocused, TRUE);
  g_string_free (xmlNormalShadedFocused, TRUE);
  g_string_free (xmlNormalUnfocused, TRUE);
  g_string_free (xmlNormalShadedUnfocused, TRUE);
  g_string_free (xmlMaximizedFocused, TRUE);
  g_string_free (xmlMaximizedShadedFocused, TRUE);
  g_string_free (xmlMaximizedUnfocused, TRUE);
  g_string_free (xmlMaximizedShadedUnfocused, TRUE);
  g_string_free (xmlUtilityFocused, TRUE);
  g_string_free (xmlUtilityUnfocused, TRUE);
  g_string_free (xmlBorder, TRUE);
}

/* Establece y escribe la aplicación de los estilos del fichero xml */

void set_xml_set_styles (GIOChannel *xmlFile)
{
  gsize bytes;
  GError *error = NULL;
  GString *xmlNormal;
  GString *xmlUtility;
  GString *xmlBorder;
  GString *xmlWindows;
  GString *xmlIcons;
  
  xmlNormal = g_string_new ("<frame_style_set name=\"normal\">\n");
  g_string_append (xmlNormal, "  <frame focus=\"yes\" state=\"normal\" resize=\"both\" style=\"normal_focused\"/>\n");
  g_string_append (xmlNormal, "  <frame focus=\"no\" state=\"normal\" resize=\"both\" style=\"normal_unfocused\"/>\n");
  g_string_append (xmlNormal, "  <frame focus=\"yes\" state=\"maximized\" style=\"maximized_focused\"/>\n");
  g_string_append (xmlNormal, "  <frame focus=\"no\" state=\"maximized\" style=\"maximized_unfocused\"/>\n");
  g_string_append (xmlNormal, "  <frame focus=\"yes\" state=\"shaded\" style=\"normal_shaded_focused\"/>\n");
  g_string_append (xmlNormal, "  <frame focus=\"no\" state=\"shaded\" style=\"normal_shaded_unfocused\"/>\n");
  g_string_append (xmlNormal, "  <frame focus=\"yes\" state=\"maximized_and_shaded\" style=\"maximized_shaded_focused\"/>\n");
  g_string_append (xmlNormal, "  <frame focus=\"no\" state=\"maximized_and_shaded\" style=\"maximized_shaded_unfocused\"/>\n");
  g_string_append (xmlNormal, "</frame_style_set>\n\n");

  xmlUtility = g_string_new ("<frame_style_set name=\"utility\" parent=\"normal\">\n");
  g_string_append (xmlUtility, "  <frame focus=\"yes\" state=\"normal\" resize=\"both\" style=\"utility_focused\"/>\n");
  g_string_append (xmlUtility, "  <frame focus=\"no\" state=\"normal\" resize=\"both\" style=\"utility_unfocused\"/>\n");
  g_string_append (xmlUtility, "  <frame focus=\"yes\" state=\"maximized\" style=\"utility_focused\"/>\n");
  g_string_append (xmlUtility, "  <frame focus=\"no\" state=\"maximized\" style=\"utility_unfocused\"/>\n");
  g_string_append (xmlUtility, "  <frame focus=\"yes\" state=\"shaded\" style=\"utility_focused\"/>\n");
  g_string_append (xmlUtility, "  <frame focus=\"no\" state=\"shaded\" style=\"utility_unfocused\"/>\n");
  g_string_append (xmlUtility, "  <frame focus=\"yes\" state=\"maximized_and_shaded\" style=\"utility_focused\"/>\n");
  g_string_append (xmlUtility, "  <frame focus=\"no\" state=\"maximized_and_shaded\" style=\"utility_unfocused\"/>\n");
  g_string_append (xmlUtility, "</frame_style_set>\n\n");

  xmlBorder = g_string_new ("<frame_style_set name=\"border\">\n");
  g_string_append (xmlBorder, "  <frame focus=\"yes\" state=\"normal\" resize=\"both\" style=\"border\"/>\n");
  g_string_append (xmlBorder, "  <frame focus=\"no\" state=\"normal\" resize=\"both\" style=\"border\"/>\n");
  g_string_append (xmlBorder, "  <frame focus=\"yes\" state=\"maximized\" style=\"border\"/>\n");
  g_string_append (xmlBorder, "  <frame focus=\"no\" state=\"maximized\" style=\"border\"/>\n");
  g_string_append (xmlBorder, "  <frame focus=\"yes\" state=\"shaded\" style=\"border\"/>\n");
  g_string_append (xmlBorder, "  <frame focus=\"no\" state=\"shaded\" style=\"border\"/>\n");
  g_string_append (xmlBorder, "  <frame focus=\"yes\" state=\"maximized_and_shaded\" style=\"border\"/>\n");
  g_string_append (xmlBorder, "  <frame focus=\"no\" state=\"maximized_and_shaded\" style=\"border\"/>\n");
  g_string_append (xmlBorder, "</frame_style_set>\n\n");

  xmlWindows = g_string_new ("<window type=\"normal\" style_set=\"normal\"/>\n");
  g_string_append (xmlWindows, "<window type=\"dialog\" style_set=\"normal\"/>\n");
  g_string_append (xmlWindows, "<window type=\"modal_dialog\" style_set=\"normal\"/>\n");
  g_string_append (xmlWindows, "<window type=\"menu\" style_set=\"normal\"/>\n");
  g_string_append (xmlWindows, "<window type=\"utility\" style_set=\"utility\"/>\n");
  g_string_append (xmlWindows, "<window type=\"border\" style_set=\"border\"/>\n\n");

  xmlIcons = g_string_new ("<menu_icon function=\"close\" state=\"normal\" draw_ops=\"close_button\"/>\n");
  g_string_append (xmlIcons, "<menu_icon function=\"maximize\" state=\"normal\" draw_ops=\"maximize_button\"/>\n");
  g_string_append (xmlIcons, "<menu_icon function=\"unmaximize\" state=\"normal\" draw_ops=\"restore_button\"/>\n");
  g_string_append (xmlIcons, "<menu_icon function=\"minimize\" state=\"normal\" draw_ops=\"minimize_button\"/>\n\n");

  g_io_channel_write_chars (xmlFile, xmlNormal->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlUtility->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlBorder->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlWindows->str, -1, &bytes, &error);
  g_io_channel_write_chars (xmlFile, xmlIcons->str, -1, &bytes, &error);

  g_string_free (xmlNormal, TRUE);
  g_string_free (xmlUtility, TRUE);
  g_string_free (xmlBorder, TRUE);
  g_string_free (xmlWindows, TRUE);
  g_string_free (xmlIcons, TRUE);
}

/* Establece y escribe el final del fichero xml */

void set_xml_end (GIOChannel *xmlFile)
{
  gsize bytes;
  GError *error = NULL;
  GString *xmlEnd;
  
  xmlEnd = g_string_new ("</metacity_theme>\n");

  g_io_channel_write_chars (xmlFile, xmlEnd->str, -1, &bytes, &error);

  g_string_free (xmlEnd, TRUE);
}
